#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class McardTemplateBenefit(object):

    def __init__(self):
        self._benefit_desc = None
        self._end_date = None
        self._ext_info = None
        self._start_date = None
        self._template_id = None
        self._title = None

    @property
    def benefit_desc(self):
        return self._benefit_desc

    @benefit_desc.setter
    def benefit_desc(self, value):
        if isinstance(value, list):
            self._benefit_desc = list()
            for i in value:
                self._benefit_desc.append(i)
    @property
    def end_date(self):
        return self._end_date

    @end_date.setter
    def end_date(self, value):
        self._end_date = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def start_date(self):
        return self._start_date

    @start_date.setter
    def start_date(self, value):
        self._start_date = value
    @property
    def template_id(self):
        return self._template_id

    @template_id.setter
    def template_id(self, value):
        self._template_id = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value


    def to_alipay_dict(self):
        params = dict()
        if self.benefit_desc:
            if isinstance(self.benefit_desc, list):
                for i in range(0, len(self.benefit_desc)):
                    element = self.benefit_desc[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.benefit_desc[i] = element.to_alipay_dict()
            if hasattr(self.benefit_desc, 'to_alipay_dict'):
                params['benefit_desc'] = self.benefit_desc.to_alipay_dict()
            else:
                params['benefit_desc'] = self.benefit_desc
        if self.end_date:
            if hasattr(self.end_date, 'to_alipay_dict'):
                params['end_date'] = self.end_date.to_alipay_dict()
            else:
                params['end_date'] = self.end_date
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.start_date:
            if hasattr(self.start_date, 'to_alipay_dict'):
                params['start_date'] = self.start_date.to_alipay_dict()
            else:
                params['start_date'] = self.start_date
        if self.template_id:
            if hasattr(self.template_id, 'to_alipay_dict'):
                params['template_id'] = self.template_id.to_alipay_dict()
            else:
                params['template_id'] = self.template_id
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = McardTemplateBenefit()
        if 'benefit_desc' in d:
            o.benefit_desc = d['benefit_desc']
        if 'end_date' in d:
            o.end_date = d['end_date']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'start_date' in d:
            o.start_date = d['start_date']
        if 'template_id' in d:
            o.template_id = d['template_id']
        if 'title' in d:
            o.title = d['title']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CommodityExtInfoConfirm(object):

    def __init__(self):
        self._city_status = None
        self._displayapp_id = None
        self._mapping_displayapp_id = None
        self._memo = None

    @property
    def city_status(self):
        return self._city_status

    @city_status.setter
    def city_status(self, value):
        self._city_status = value
    @property
    def displayapp_id(self):
        return self._displayapp_id

    @displayapp_id.setter
    def displayapp_id(self, value):
        self._displayapp_id = value
    @property
    def mapping_displayapp_id(self):
        return self._mapping_displayapp_id

    @mapping_displayapp_id.setter
    def mapping_displayapp_id(self, value):
        self._mapping_displayapp_id = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value


    def to_alipay_dict(self):
        params = dict()
        if self.city_status:
            if hasattr(self.city_status, 'to_alipay_dict'):
                params['city_status'] = self.city_status.to_alipay_dict()
            else:
                params['city_status'] = self.city_status
        if self.displayapp_id:
            if hasattr(self.displayapp_id, 'to_alipay_dict'):
                params['displayapp_id'] = self.displayapp_id.to_alipay_dict()
            else:
                params['displayapp_id'] = self.displayapp_id
        if self.mapping_displayapp_id:
            if hasattr(self.mapping_displayapp_id, 'to_alipay_dict'):
                params['mapping_displayapp_id'] = self.mapping_displayapp_id.to_alipay_dict()
            else:
                params['mapping_displayapp_id'] = self.mapping_displayapp_id
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CommodityExtInfoConfirm()
        if 'city_status' in d:
            o.city_status = d['city_status']
        if 'displayapp_id' in d:
            o.displayapp_id = d['displayapp_id']
        if 'mapping_displayapp_id' in d:
            o.mapping_displayapp_id = d['mapping_displayapp_id']
        if 'memo' in d:
            o.memo = d['memo']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ContractConsultResultVO import ContractConsultResultVO


class InterTradeConsultOpenApiResult(object):

    def __init__(self):
        self._contracts = None
        self._need_approval = None

    @property
    def contracts(self):
        return self._contracts

    @contracts.setter
    def contracts(self, value):
        if isinstance(value, list):
            self._contracts = list()
            for i in value:
                if isinstance(i, ContractConsultResultVO):
                    self._contracts.append(i)
                else:
                    self._contracts.append(ContractConsultResultVO.from_alipay_dict(i))
    @property
    def need_approval(self):
        return self._need_approval

    @need_approval.setter
    def need_approval(self, value):
        self._need_approval = value


    def to_alipay_dict(self):
        params = dict()
        if self.contracts:
            if isinstance(self.contracts, list):
                for i in range(0, len(self.contracts)):
                    element = self.contracts[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.contracts[i] = element.to_alipay_dict()
            if hasattr(self.contracts, 'to_alipay_dict'):
                params['contracts'] = self.contracts.to_alipay_dict()
            else:
                params['contracts'] = self.contracts
        if self.need_approval:
            if hasattr(self.need_approval, 'to_alipay_dict'):
                params['need_approval'] = self.need_approval.to_alipay_dict()
            else:
                params['need_approval'] = self.need_approval
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InterTradeConsultOpenApiResult()
        if 'contracts' in d:
            o.contracts = d['contracts']
        if 'need_approval' in d:
            o.need_approval = d['need_approval']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.GavintestNewLeveaOne import GavintestNewLeveaOne


class AlipayOpenPublicComptestCreateModel(object):

    def __init__(self):
        self._address = None
        self._string = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def string(self):
        return self._string

    @string.setter
    def string(self, value):
        if isinstance(value, list):
            self._string = list()
            for i in value:
                if isinstance(i, GavintestNewLeveaOne):
                    self._string.append(i)
                else:
                    self._string.append(GavintestNewLeveaOne.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.address:
            if hasattr(self.address, 'to_alipay_dict'):
                params['address'] = self.address.to_alipay_dict()
            else:
                params['address'] = self.address
        if self.string:
            if isinstance(self.string, list):
                for i in range(0, len(self.string)):
                    element = self.string[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.string[i] = element.to_alipay_dict()
            if hasattr(self.string, 'to_alipay_dict'):
                params['string'] = self.string.to_alipay_dict()
            else:
                params['string'] = self.string
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenPublicComptestCreateModel()
        if 'address' in d:
            o.address = d['address']
        if 'string' in d:
            o.string = d['string']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class KoubeiQualityTestShieldCaselaunchApplyResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiQualityTestShieldCaselaunchApplyResponse, self).__init__()
        self._ext_infos = None

    @property
    def ext_infos(self):
        return self._ext_infos

    @ext_infos.setter
    def ext_infos(self, value):
        self._ext_infos = value

    def parse_response_content(self, response_content):
        response = super(KoubeiQualityTestShieldCaselaunchApplyResponse, self).parse_response_content(response_content)
        if 'ext_infos' in response:
            self.ext_infos = response['ext_infos']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceOperationBrandsolutionEnrollmerchantQueryModel(object):

    def __init__(self):
        self._activity_id = None
        self._pids = None

    @property
    def activity_id(self):
        return self._activity_id

    @activity_id.setter
    def activity_id(self, value):
        self._activity_id = value
    @property
    def pids(self):
        return self._pids

    @pids.setter
    def pids(self, value):
        if isinstance(value, list):
            self._pids = list()
            for i in value:
                self._pids.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.activity_id:
            if hasattr(self.activity_id, 'to_alipay_dict'):
                params['activity_id'] = self.activity_id.to_alipay_dict()
            else:
                params['activity_id'] = self.activity_id
        if self.pids:
            if isinstance(self.pids, list):
                for i in range(0, len(self.pids)):
                    element = self.pids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.pids[i] = element.to_alipay_dict()
            if hasattr(self.pids, 'to_alipay_dict'):
                params['pids'] = self.pids.to_alipay_dict()
            else:
                params['pids'] = self.pids
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceOperationBrandsolutionEnrollmerchantQueryModel()
        if 'activity_id' in d:
            o.activity_id = d['activity_id']
        if 'pids' in d:
            o.pids = d['pids']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class SsdataDataserviceRiskBusinesslicenseCertifyResponse(AlipayResponse):

    def __init__(self):
        super(SsdataDataserviceRiskBusinesslicenseCertifyResponse, self).__init__()
        self._address = None
        self._bis_token = None
        self._check_result = None
        self._credit_code = None
        self._ent_legal_name = None
        self._ent_name = None
        self._expires = None
        self._expires_end = None
        self._expires_start = None
        self._match_param = None
        self._no_match_param = None
        self._unique_id = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def bis_token(self):
        return self._bis_token

    @bis_token.setter
    def bis_token(self, value):
        self._bis_token = value
    @property
    def check_result(self):
        return self._check_result

    @check_result.setter
    def check_result(self, value):
        self._check_result = value
    @property
    def credit_code(self):
        return self._credit_code

    @credit_code.setter
    def credit_code(self, value):
        self._credit_code = value
    @property
    def ent_legal_name(self):
        return self._ent_legal_name

    @ent_legal_name.setter
    def ent_legal_name(self, value):
        self._ent_legal_name = value
    @property
    def ent_name(self):
        return self._ent_name

    @ent_name.setter
    def ent_name(self, value):
        self._ent_name = value
    @property
    def expires(self):
        return self._expires

    @expires.setter
    def expires(self, value):
        self._expires = value
    @property
    def expires_end(self):
        return self._expires_end

    @expires_end.setter
    def expires_end(self, value):
        self._expires_end = value
    @property
    def expires_start(self):
        return self._expires_start

    @expires_start.setter
    def expires_start(self, value):
        self._expires_start = value
    @property
    def match_param(self):
        return self._match_param

    @match_param.setter
    def match_param(self, value):
        self._match_param = value
    @property
    def no_match_param(self):
        return self._no_match_param

    @no_match_param.setter
    def no_match_param(self, value):
        self._no_match_param = value
    @property
    def unique_id(self):
        return self._unique_id

    @unique_id.setter
    def unique_id(self, value):
        self._unique_id = value

    def parse_response_content(self, response_content):
        response = super(SsdataDataserviceRiskBusinesslicenseCertifyResponse, self).parse_response_content(response_content)
        if 'address' in response:
            self.address = response['address']
        if 'bis_token' in response:
            self.bis_token = response['bis_token']
        if 'check_result' in response:
            self.check_result = response['check_result']
        if 'credit_code' in response:
            self.credit_code = response['credit_code']
        if 'ent_legal_name' in response:
            self.ent_legal_name = response['ent_legal_name']
        if 'ent_name' in response:
            self.ent_name = response['ent_name']
        if 'expires' in response:
            self.expires = response['expires']
        if 'expires_end' in response:
            self.expires_end = response['expires_end']
        if 'expires_start' in response:
            self.expires_start = response['expires_start']
        if 'match_param' in response:
            self.match_param = response['match_param']
        if 'no_match_param' in response:
            self.no_match_param = response['no_match_param']
        if 'unique_id' in response:
            self.unique_id = response['unique_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AssetsDetailParams import AssetsDetailParams
from alipay.aop.api.domain.SubChannelList import SubChannelList


class ChannelInfo(object):

    def __init__(self):
        self._asset_id = None
        self._asset_type = None
        self._asset_type_code = None
        self._assets_detail_params = None
        self._available_amount = None
        self._close_error_code = None
        self._close_error_msg = None
        self._compatible_channel_index = None
        self._enable = None
        self._enough = None
        self._inst_id = None
        self._limit_amount = None
        self._logo = None
        self._name = None
        self._recommend_text = None
        self._recommend_tip = None
        self._signed = None
        self._sub_channel_list = None

    @property
    def asset_id(self):
        return self._asset_id

    @asset_id.setter
    def asset_id(self, value):
        self._asset_id = value
    @property
    def asset_type(self):
        return self._asset_type

    @asset_type.setter
    def asset_type(self, value):
        self._asset_type = value
    @property
    def asset_type_code(self):
        return self._asset_type_code

    @asset_type_code.setter
    def asset_type_code(self, value):
        self._asset_type_code = value
    @property
    def assets_detail_params(self):
        return self._assets_detail_params

    @assets_detail_params.setter
    def assets_detail_params(self, value):
        if isinstance(value, AssetsDetailParams):
            self._assets_detail_params = value
        else:
            self._assets_detail_params = AssetsDetailParams.from_alipay_dict(value)
    @property
    def available_amount(self):
        return self._available_amount

    @available_amount.setter
    def available_amount(self, value):
        self._available_amount = value
    @property
    def close_error_code(self):
        return self._close_error_code

    @close_error_code.setter
    def close_error_code(self, value):
        self._close_error_code = value
    @property
    def close_error_msg(self):
        return self._close_error_msg

    @close_error_msg.setter
    def close_error_msg(self, value):
        self._close_error_msg = value
    @property
    def compatible_channel_index(self):
        return self._compatible_channel_index

    @compatible_channel_index.setter
    def compatible_channel_index(self, value):
        self._compatible_channel_index = value
    @property
    def enable(self):
        return self._enable

    @enable.setter
    def enable(self, value):
        self._enable = value
    @property
    def enough(self):
        return self._enough

    @enough.setter
    def enough(self, value):
        self._enough = value
    @property
    def inst_id(self):
        return self._inst_id

    @inst_id.setter
    def inst_id(self, value):
        self._inst_id = value
    @property
    def limit_amount(self):
        return self._limit_amount

    @limit_amount.setter
    def limit_amount(self, value):
        self._limit_amount = value
    @property
    def logo(self):
        return self._logo

    @logo.setter
    def logo(self, value):
        self._logo = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def recommend_text(self):
        return self._recommend_text

    @recommend_text.setter
    def recommend_text(self, value):
        self._recommend_text = value
    @property
    def recommend_tip(self):
        return self._recommend_tip

    @recommend_tip.setter
    def recommend_tip(self, value):
        self._recommend_tip = value
    @property
    def signed(self):
        return self._signed

    @signed.setter
    def signed(self, value):
        self._signed = value
    @property
    def sub_channel_list(self):
        return self._sub_channel_list

    @sub_channel_list.setter
    def sub_channel_list(self, value):
        if isinstance(value, list):
            self._sub_channel_list = list()
            for i in value:
                if isinstance(i, SubChannelList):
                    self._sub_channel_list.append(i)
                else:
                    self._sub_channel_list.append(SubChannelList.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.asset_id:
            if hasattr(self.asset_id, 'to_alipay_dict'):
                params['asset_id'] = self.asset_id.to_alipay_dict()
            else:
                params['asset_id'] = self.asset_id
        if self.asset_type:
            if hasattr(self.asset_type, 'to_alipay_dict'):
                params['asset_type'] = self.asset_type.to_alipay_dict()
            else:
                params['asset_type'] = self.asset_type
        if self.asset_type_code:
            if hasattr(self.asset_type_code, 'to_alipay_dict'):
                params['asset_type_code'] = self.asset_type_code.to_alipay_dict()
            else:
                params['asset_type_code'] = self.asset_type_code
        if self.assets_detail_params:
            if hasattr(self.assets_detail_params, 'to_alipay_dict'):
                params['assets_detail_params'] = self.assets_detail_params.to_alipay_dict()
            else:
                params['assets_detail_params'] = self.assets_detail_params
        if self.available_amount:
            if hasattr(self.available_amount, 'to_alipay_dict'):
                params['available_amount'] = self.available_amount.to_alipay_dict()
            else:
                params['available_amount'] = self.available_amount
        if self.close_error_code:
            if hasattr(self.close_error_code, 'to_alipay_dict'):
                params['close_error_code'] = self.close_error_code.to_alipay_dict()
            else:
                params['close_error_code'] = self.close_error_code
        if self.close_error_msg:
            if hasattr(self.close_error_msg, 'to_alipay_dict'):
                params['close_error_msg'] = self.close_error_msg.to_alipay_dict()
            else:
                params['close_error_msg'] = self.close_error_msg
        if self.compatible_channel_index:
            if hasattr(self.compatible_channel_index, 'to_alipay_dict'):
                params['compatible_channel_index'] = self.compatible_channel_index.to_alipay_dict()
            else:
                params['compatible_channel_index'] = self.compatible_channel_index
        if self.enable:
            if hasattr(self.enable, 'to_alipay_dict'):
                params['enable'] = self.enable.to_alipay_dict()
            else:
                params['enable'] = self.enable
        if self.enough:
            if hasattr(self.enough, 'to_alipay_dict'):
                params['enough'] = self.enough.to_alipay_dict()
            else:
                params['enough'] = self.enough
        if self.inst_id:
            if hasattr(self.inst_id, 'to_alipay_dict'):
                params['inst_id'] = self.inst_id.to_alipay_dict()
            else:
                params['inst_id'] = self.inst_id
        if self.limit_amount:
            if hasattr(self.limit_amount, 'to_alipay_dict'):
                params['limit_amount'] = self.limit_amount.to_alipay_dict()
            else:
                params['limit_amount'] = self.limit_amount
        if self.logo:
            if hasattr(self.logo, 'to_alipay_dict'):
                params['logo'] = self.logo.to_alipay_dict()
            else:
                params['logo'] = self.logo
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.recommend_text:
            if hasattr(self.recommend_text, 'to_alipay_dict'):
                params['recommend_text'] = self.recommend_text.to_alipay_dict()
            else:
                params['recommend_text'] = self.recommend_text
        if self.recommend_tip:
            if hasattr(self.recommend_tip, 'to_alipay_dict'):
                params['recommend_tip'] = self.recommend_tip.to_alipay_dict()
            else:
                params['recommend_tip'] = self.recommend_tip
        if self.signed:
            if hasattr(self.signed, 'to_alipay_dict'):
                params['signed'] = self.signed.to_alipay_dict()
            else:
                params['signed'] = self.signed
        if self.sub_channel_list:
            if isinstance(self.sub_channel_list, list):
                for i in range(0, len(self.sub_channel_list)):
                    element = self.sub_channel_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.sub_channel_list[i] = element.to_alipay_dict()
            if hasattr(self.sub_channel_list, 'to_alipay_dict'):
                params['sub_channel_list'] = self.sub_channel_list.to_alipay_dict()
            else:
                params['sub_channel_list'] = self.sub_channel_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ChannelInfo()
        if 'asset_id' in d:
            o.asset_id = d['asset_id']
        if 'asset_type' in d:
            o.asset_type = d['asset_type']
        if 'asset_type_code' in d:
            o.asset_type_code = d['asset_type_code']
        if 'assets_detail_params' in d:
            o.assets_detail_params = d['assets_detail_params']
        if 'available_amount' in d:
            o.available_amount = d['available_amount']
        if 'close_error_code' in d:
            o.close_error_code = d['close_error_code']
        if 'close_error_msg' in d:
            o.close_error_msg = d['close_error_msg']
        if 'compatible_channel_index' in d:
            o.compatible_channel_index = d['compatible_channel_index']
        if 'enable' in d:
            o.enable = d['enable']
        if 'enough' in d:
            o.enough = d['enough']
        if 'inst_id' in d:
            o.inst_id = d['inst_id']
        if 'limit_amount' in d:
            o.limit_amount = d['limit_amount']
        if 'logo' in d:
            o.logo = d['logo']
        if 'name' in d:
            o.name = d['name']
        if 'recommend_text' in d:
            o.recommend_text = d['recommend_text']
        if 'recommend_tip' in d:
            o.recommend_tip = d['recommend_tip']
        if 'signed' in d:
            o.signed = d['signed']
        if 'sub_channel_list' in d:
            o.sub_channel_list = d['sub_channel_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ConsultActivityInfo import ConsultActivityInfo


class AlipayMarketingActivityConsultModel(object):

    def __init__(self):
        self._consult_activity_info_list = None
        self._merchant_id = None
        self._user_id = None

    @property
    def consult_activity_info_list(self):
        return self._consult_activity_info_list

    @consult_activity_info_list.setter
    def consult_activity_info_list(self, value):
        if isinstance(value, list):
            self._consult_activity_info_list = list()
            for i in value:
                if isinstance(i, ConsultActivityInfo):
                    self._consult_activity_info_list.append(i)
                else:
                    self._consult_activity_info_list.append(ConsultActivityInfo.from_alipay_dict(i))
    @property
    def merchant_id(self):
        return self._merchant_id

    @merchant_id.setter
    def merchant_id(self, value):
        self._merchant_id = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.consult_activity_info_list:
            if isinstance(self.consult_activity_info_list, list):
                for i in range(0, len(self.consult_activity_info_list)):
                    element = self.consult_activity_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.consult_activity_info_list[i] = element.to_alipay_dict()
            if hasattr(self.consult_activity_info_list, 'to_alipay_dict'):
                params['consult_activity_info_list'] = self.consult_activity_info_list.to_alipay_dict()
            else:
                params['consult_activity_info_list'] = self.consult_activity_info_list
        if self.merchant_id:
            if hasattr(self.merchant_id, 'to_alipay_dict'):
                params['merchant_id'] = self.merchant_id.to_alipay_dict()
            else:
                params['merchant_id'] = self.merchant_id
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingActivityConsultModel()
        if 'consult_activity_info_list' in d:
            o.consult_activity_info_list = d['consult_activity_info_list']
        if 'merchant_id' in d:
            o.merchant_id = d['merchant_id']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.PlateInfoForYiCai import PlateInfoForYiCai


class AntfortuneQuotationPlateIndexQueryResponse(AlipayResponse):

    def __init__(self):
        super(AntfortuneQuotationPlateIndexQueryResponse, self).__init__()
        self._plate_list = None
        self._res = None

    @property
    def plate_list(self):
        return self._plate_list

    @plate_list.setter
    def plate_list(self, value):
        if isinstance(value, list):
            self._plate_list = list()
            for i in value:
                if isinstance(i, PlateInfoForYiCai):
                    self._plate_list.append(i)
                else:
                    self._plate_list.append(PlateInfoForYiCai.from_alipay_dict(i))
    @property
    def res(self):
        return self._res

    @res.setter
    def res(self, value):
        self._res = value

    def parse_response_content(self, response_content):
        response = super(AntfortuneQuotationPlateIndexQueryResponse, self).parse_response_content(response_content)
        if 'plate_list' in response:
            self.plate_list = response['plate_list']
        if 'res' in response:
            self.res = response['res']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AlipayMarketingIbsInfo import AlipayMarketingIbsInfo


class AlipayMarketingExtData(object):

    def __init__(self):
        self._lbs_info = None
        self._out_user_id = None

    @property
    def lbs_info(self):
        return self._lbs_info

    @lbs_info.setter
    def lbs_info(self, value):
        if isinstance(value, AlipayMarketingIbsInfo):
            self._lbs_info = value
        else:
            self._lbs_info = AlipayMarketingIbsInfo.from_alipay_dict(value)
    @property
    def out_user_id(self):
        return self._out_user_id

    @out_user_id.setter
    def out_user_id(self, value):
        self._out_user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.lbs_info:
            if hasattr(self.lbs_info, 'to_alipay_dict'):
                params['lbs_info'] = self.lbs_info.to_alipay_dict()
            else:
                params['lbs_info'] = self.lbs_info
        if self.out_user_id:
            if hasattr(self.out_user_id, 'to_alipay_dict'):
                params['out_user_id'] = self.out_user_id.to_alipay_dict()
            else:
                params['out_user_id'] = self.out_user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingExtData()
        if 'lbs_info' in d:
            o.lbs_info = d['lbs_info']
        if 'out_user_id' in d:
            o.out_user_id = d['out_user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ScenicInfo(object):

    def __init__(self):
        self._address = None
        self._city_name = None
        self._latitude = None
        self._level = None
        self._longitude = None
        self._province_name = None
        self._scenic_id = None
        self._scenic_name = None
        self._telephone = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def city_name(self):
        return self._city_name

    @city_name.setter
    def city_name(self, value):
        self._city_name = value
    @property
    def latitude(self):
        return self._latitude

    @latitude.setter
    def latitude(self, value):
        self._latitude = value
    @property
    def level(self):
        return self._level

    @level.setter
    def level(self, value):
        self._level = value
    @property
    def longitude(self):
        return self._longitude

    @longitude.setter
    def longitude(self, value):
        self._longitude = value
    @property
    def province_name(self):
        return self._province_name

    @province_name.setter
    def province_name(self, value):
        self._province_name = value
    @property
    def scenic_id(self):
        return self._scenic_id

    @scenic_id.setter
    def scenic_id(self, value):
        self._scenic_id = value
    @property
    def scenic_name(self):
        return self._scenic_name

    @scenic_name.setter
    def scenic_name(self, value):
        self._scenic_name = value
    @property
    def telephone(self):
        return self._telephone

    @telephone.setter
    def telephone(self, value):
        self._telephone = value


    def to_alipay_dict(self):
        params = dict()
        if self.address:
            if hasattr(self.address, 'to_alipay_dict'):
                params['address'] = self.address.to_alipay_dict()
            else:
                params['address'] = self.address
        if self.city_name:
            if hasattr(self.city_name, 'to_alipay_dict'):
                params['city_name'] = self.city_name.to_alipay_dict()
            else:
                params['city_name'] = self.city_name
        if self.latitude:
            if hasattr(self.latitude, 'to_alipay_dict'):
                params['latitude'] = self.latitude.to_alipay_dict()
            else:
                params['latitude'] = self.latitude
        if self.level:
            if hasattr(self.level, 'to_alipay_dict'):
                params['level'] = self.level.to_alipay_dict()
            else:
                params['level'] = self.level
        if self.longitude:
            if hasattr(self.longitude, 'to_alipay_dict'):
                params['longitude'] = self.longitude.to_alipay_dict()
            else:
                params['longitude'] = self.longitude
        if self.province_name:
            if hasattr(self.province_name, 'to_alipay_dict'):
                params['province_name'] = self.province_name.to_alipay_dict()
            else:
                params['province_name'] = self.province_name
        if self.scenic_id:
            if hasattr(self.scenic_id, 'to_alipay_dict'):
                params['scenic_id'] = self.scenic_id.to_alipay_dict()
            else:
                params['scenic_id'] = self.scenic_id
        if self.scenic_name:
            if hasattr(self.scenic_name, 'to_alipay_dict'):
                params['scenic_name'] = self.scenic_name.to_alipay_dict()
            else:
                params['scenic_name'] = self.scenic_name
        if self.telephone:
            if hasattr(self.telephone, 'to_alipay_dict'):
                params['telephone'] = self.telephone.to_alipay_dict()
            else:
                params['telephone'] = self.telephone
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ScenicInfo()
        if 'address' in d:
            o.address = d['address']
        if 'city_name' in d:
            o.city_name = d['city_name']
        if 'latitude' in d:
            o.latitude = d['latitude']
        if 'level' in d:
            o.level = d['level']
        if 'longitude' in d:
            o.longitude = d['longitude']
        if 'province_name' in d:
            o.province_name = d['province_name']
        if 'scenic_id' in d:
            o.scenic_id = d['scenic_id']
        if 'scenic_name' in d:
            o.scenic_name = d['scenic_name']
        if 'telephone' in d:
            o.telephone = d['telephone']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayInsSceneInsassetprodPetprofileQueryModel(object):

    def __init__(self):
        self._channel = None
        self._pet_id = None

    @property
    def channel(self):
        return self._channel

    @channel.setter
    def channel(self, value):
        self._channel = value
    @property
    def pet_id(self):
        return self._pet_id

    @pet_id.setter
    def pet_id(self, value):
        self._pet_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.channel:
            if hasattr(self.channel, 'to_alipay_dict'):
                params['channel'] = self.channel.to_alipay_dict()
            else:
                params['channel'] = self.channel
        if self.pet_id:
            if hasattr(self.pet_id, 'to_alipay_dict'):
                params['pet_id'] = self.pet_id.to_alipay_dict()
            else:
                params['pet_id'] = self.pet_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsSceneInsassetprodPetprofileQueryModel()
        if 'channel' in d:
            o.channel = d['channel']
        if 'pet_id' in d:
            o.pet_id = d['pet_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMarketingCampaignRuleCrowdDeleteModel(object):

    def __init__(self):
        self._mpid = None
        self._ruleid = None

    @property
    def mpid(self):
        return self._mpid

    @mpid.setter
    def mpid(self, value):
        self._mpid = value
    @property
    def ruleid(self):
        return self._ruleid

    @ruleid.setter
    def ruleid(self, value):
        self._ruleid = value


    def to_alipay_dict(self):
        params = dict()
        if self.mpid:
            if hasattr(self.mpid, 'to_alipay_dict'):
                params['mpid'] = self.mpid.to_alipay_dict()
            else:
                params['mpid'] = self.mpid
        if self.ruleid:
            if hasattr(self.ruleid, 'to_alipay_dict'):
                params['ruleid'] = self.ruleid.to_alipay_dict()
            else:
                params['ruleid'] = self.ruleid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingCampaignRuleCrowdDeleteModel()
        if 'mpid' in d:
            o.mpid = d['mpid']
        if 'ruleid' in d:
            o.ruleid = d['ruleid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniInnerbaseinfoParameterVerifyModel(object):

    def __init__(self):
        self._verify_type = None
        self._verify_value = None

    @property
    def verify_type(self):
        return self._verify_type

    @verify_type.setter
    def verify_type(self, value):
        self._verify_type = value
    @property
    def verify_value(self):
        return self._verify_value

    @verify_value.setter
    def verify_value(self, value):
        self._verify_value = value


    def to_alipay_dict(self):
        params = dict()
        if self.verify_type:
            if hasattr(self.verify_type, 'to_alipay_dict'):
                params['verify_type'] = self.verify_type.to_alipay_dict()
            else:
                params['verify_type'] = self.verify_type
        if self.verify_value:
            if hasattr(self.verify_value, 'to_alipay_dict'):
                params['verify_value'] = self.verify_value.to_alipay_dict()
            else:
                params['verify_value'] = self.verify_value
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniInnerbaseinfoParameterVerifyModel()
        if 'verify_type' in d:
            o.verify_type = d['verify_type']
        if 'verify_value' in d:
            o.verify_value = d['verify_value']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserAgreementExecutionplanModifyModel(object):

    def __init__(self):
        self._agreement_no = None
        self._deduct_time = None
        self._memo = None

    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def deduct_time(self):
        return self._deduct_time

    @deduct_time.setter
    def deduct_time(self, value):
        self._deduct_time = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value


    def to_alipay_dict(self):
        params = dict()
        if self.agreement_no:
            if hasattr(self.agreement_no, 'to_alipay_dict'):
                params['agreement_no'] = self.agreement_no.to_alipay_dict()
            else:
                params['agreement_no'] = self.agreement_no
        if self.deduct_time:
            if hasattr(self.deduct_time, 'to_alipay_dict'):
                params['deduct_time'] = self.deduct_time.to_alipay_dict()
            else:
                params['deduct_time'] = self.deduct_time
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserAgreementExecutionplanModifyModel()
        if 'agreement_no' in d:
            o.agreement_no = d['agreement_no']
        if 'deduct_time' in d:
            o.deduct_time = d['deduct_time']
        if 'memo' in d:
            o.memo = d['memo']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayUserMemberSceneQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserMemberSceneQueryResponse, self).__init__()
        self._state = None

    @property
    def state(self):
        return self._state

    @state.setter
    def state(self, value):
        self._state = value

    def parse_response_content(self, response_content):
        response = super(AlipayUserMemberSceneQueryResponse, self).parse_response_content(response_content)
        if 'state' in response:
            self.state = response['state']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MybankCreditLoanapplyQrcodeCreateModel(object):

    def __init__(self):
        self._bank_card_category = None
        self._beneficiary_account = None
        self._beneficiary_name = None
        self._deposit_bank = None
        self._deposit_bank_cnaps_code = None
        self._head_bank_cnaps_code = None
        self._invalid_date = None
        self._order_amt = None
        self._order_no = None

    @property
    def bank_card_category(self):
        return self._bank_card_category

    @bank_card_category.setter
    def bank_card_category(self, value):
        self._bank_card_category = value
    @property
    def beneficiary_account(self):
        return self._beneficiary_account

    @beneficiary_account.setter
    def beneficiary_account(self, value):
        self._beneficiary_account = value
    @property
    def beneficiary_name(self):
        return self._beneficiary_name

    @beneficiary_name.setter
    def beneficiary_name(self, value):
        self._beneficiary_name = value
    @property
    def deposit_bank(self):
        return self._deposit_bank

    @deposit_bank.setter
    def deposit_bank(self, value):
        self._deposit_bank = value
    @property
    def deposit_bank_cnaps_code(self):
        return self._deposit_bank_cnaps_code

    @deposit_bank_cnaps_code.setter
    def deposit_bank_cnaps_code(self, value):
        self._deposit_bank_cnaps_code = value
    @property
    def head_bank_cnaps_code(self):
        return self._head_bank_cnaps_code

    @head_bank_cnaps_code.setter
    def head_bank_cnaps_code(self, value):
        self._head_bank_cnaps_code = value
    @property
    def invalid_date(self):
        return self._invalid_date

    @invalid_date.setter
    def invalid_date(self, value):
        self._invalid_date = value
    @property
    def order_amt(self):
        return self._order_amt

    @order_amt.setter
    def order_amt(self, value):
        self._order_amt = value
    @property
    def order_no(self):
        return self._order_no

    @order_no.setter
    def order_no(self, value):
        self._order_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.bank_card_category:
            if hasattr(self.bank_card_category, 'to_alipay_dict'):
                params['bank_card_category'] = self.bank_card_category.to_alipay_dict()
            else:
                params['bank_card_category'] = self.bank_card_category
        if self.beneficiary_account:
            if hasattr(self.beneficiary_account, 'to_alipay_dict'):
                params['beneficiary_account'] = self.beneficiary_account.to_alipay_dict()
            else:
                params['beneficiary_account'] = self.beneficiary_account
        if self.beneficiary_name:
            if hasattr(self.beneficiary_name, 'to_alipay_dict'):
                params['beneficiary_name'] = self.beneficiary_name.to_alipay_dict()
            else:
                params['beneficiary_name'] = self.beneficiary_name
        if self.deposit_bank:
            if hasattr(self.deposit_bank, 'to_alipay_dict'):
                params['deposit_bank'] = self.deposit_bank.to_alipay_dict()
            else:
                params['deposit_bank'] = self.deposit_bank
        if self.deposit_bank_cnaps_code:
            if hasattr(self.deposit_bank_cnaps_code, 'to_alipay_dict'):
                params['deposit_bank_cnaps_code'] = self.deposit_bank_cnaps_code.to_alipay_dict()
            else:
                params['deposit_bank_cnaps_code'] = self.deposit_bank_cnaps_code
        if self.head_bank_cnaps_code:
            if hasattr(self.head_bank_cnaps_code, 'to_alipay_dict'):
                params['head_bank_cnaps_code'] = self.head_bank_cnaps_code.to_alipay_dict()
            else:
                params['head_bank_cnaps_code'] = self.head_bank_cnaps_code
        if self.invalid_date:
            if hasattr(self.invalid_date, 'to_alipay_dict'):
                params['invalid_date'] = self.invalid_date.to_alipay_dict()
            else:
                params['invalid_date'] = self.invalid_date
        if self.order_amt:
            if hasattr(self.order_amt, 'to_alipay_dict'):
                params['order_amt'] = self.order_amt.to_alipay_dict()
            else:
                params['order_amt'] = self.order_amt
        if self.order_no:
            if hasattr(self.order_no, 'to_alipay_dict'):
                params['order_no'] = self.order_no.to_alipay_dict()
            else:
                params['order_no'] = self.order_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankCreditLoanapplyQrcodeCreateModel()
        if 'bank_card_category' in d:
            o.bank_card_category = d['bank_card_category']
        if 'beneficiary_account' in d:
            o.beneficiary_account = d['beneficiary_account']
        if 'beneficiary_name' in d:
            o.beneficiary_name = d['beneficiary_name']
        if 'deposit_bank' in d:
            o.deposit_bank = d['deposit_bank']
        if 'deposit_bank_cnaps_code' in d:
            o.deposit_bank_cnaps_code = d['deposit_bank_cnaps_code']
        if 'head_bank_cnaps_code' in d:
            o.head_bank_cnaps_code = d['head_bank_cnaps_code']
        if 'invalid_date' in d:
            o.invalid_date = d['invalid_date']
        if 'order_amt' in d:
            o.order_amt = d['order_amt']
        if 'order_no' in d:
            o.order_no = d['order_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class ZhimaCreditPeZmgoPreconsultQueryResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaCreditPeZmgoPreconsultQueryResponse, self).__init__()
        self._admittance = None

    @property
    def admittance(self):
        return self._admittance

    @admittance.setter
    def admittance(self, value):
        self._admittance = value

    def parse_response_content(self, response_content):
        response = super(ZhimaCreditPeZmgoPreconsultQueryResponse, self).parse_response_content(response_content)
        if 'admittance' in response:
            self.admittance = response['admittance']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PosDishMaterialModel(object):

    def __init__(self):
        self._material_id = None
        self._material_name = None
        self._sell_price = None
        self._sort = None

    @property
    def material_id(self):
        return self._material_id

    @material_id.setter
    def material_id(self, value):
        self._material_id = value
    @property
    def material_name(self):
        return self._material_name

    @material_name.setter
    def material_name(self, value):
        self._material_name = value
    @property
    def sell_price(self):
        return self._sell_price

    @sell_price.setter
    def sell_price(self, value):
        self._sell_price = value
    @property
    def sort(self):
        return self._sort

    @sort.setter
    def sort(self, value):
        self._sort = value


    def to_alipay_dict(self):
        params = dict()
        if self.material_id:
            if hasattr(self.material_id, 'to_alipay_dict'):
                params['material_id'] = self.material_id.to_alipay_dict()
            else:
                params['material_id'] = self.material_id
        if self.material_name:
            if hasattr(self.material_name, 'to_alipay_dict'):
                params['material_name'] = self.material_name.to_alipay_dict()
            else:
                params['material_name'] = self.material_name
        if self.sell_price:
            if hasattr(self.sell_price, 'to_alipay_dict'):
                params['sell_price'] = self.sell_price.to_alipay_dict()
            else:
                params['sell_price'] = self.sell_price
        if self.sort:
            if hasattr(self.sort, 'to_alipay_dict'):
                params['sort'] = self.sort.to_alipay_dict()
            else:
                params['sort'] = self.sort
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PosDishMaterialModel()
        if 'material_id' in d:
            o.material_id = d['material_id']
        if 'material_name' in d:
            o.material_name = d['material_name']
        if 'sell_price' in d:
            o.sell_price = d['sell_price']
        if 'sort' in d:
            o.sort = d['sort']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class IsvShopDishModel(object):

    def __init__(self):
        self._content = None
        self._dish_type_id = None
        self._dish_type_name = None
        self._good_level = None
        self._merchant_sold_cnt_seven_d = None
        self._merchant_sold_cnt_thirty_d = None
        self._merchant_sold_reusercnt_thirty_d = None
        self._merchant_sold_usercnt_thirty_d = None
        self._name = None
        self._outer_dish_id = None
        self._pict = None
        self._platform = None
        self._price = None
        self._quantity = None
        self._shop_id = None
        self._sold_cnt_seven_d = None
        self._sold_cnt_thirty_d = None
        self._sold_reusercnt_thirty_d = None
        self._sold_usercnt_thirty_d = None
        self._sort_col = None
        self._unit = None

    @property
    def content(self):
        return self._content

    @content.setter
    def content(self, value):
        self._content = value
    @property
    def dish_type_id(self):
        return self._dish_type_id

    @dish_type_id.setter
    def dish_type_id(self, value):
        self._dish_type_id = value
    @property
    def dish_type_name(self):
        return self._dish_type_name

    @dish_type_name.setter
    def dish_type_name(self, value):
        self._dish_type_name = value
    @property
    def good_level(self):
        return self._good_level

    @good_level.setter
    def good_level(self, value):
        self._good_level = value
    @property
    def merchant_sold_cnt_seven_d(self):
        return self._merchant_sold_cnt_seven_d

    @merchant_sold_cnt_seven_d.setter
    def merchant_sold_cnt_seven_d(self, value):
        self._merchant_sold_cnt_seven_d = value
    @property
    def merchant_sold_cnt_thirty_d(self):
        return self._merchant_sold_cnt_thirty_d

    @merchant_sold_cnt_thirty_d.setter
    def merchant_sold_cnt_thirty_d(self, value):
        self._merchant_sold_cnt_thirty_d = value
    @property
    def merchant_sold_reusercnt_thirty_d(self):
        return self._merchant_sold_reusercnt_thirty_d

    @merchant_sold_reusercnt_thirty_d.setter
    def merchant_sold_reusercnt_thirty_d(self, value):
        self._merchant_sold_reusercnt_thirty_d = value
    @property
    def merchant_sold_usercnt_thirty_d(self):
        return self._merchant_sold_usercnt_thirty_d

    @merchant_sold_usercnt_thirty_d.setter
    def merchant_sold_usercnt_thirty_d(self, value):
        self._merchant_sold_usercnt_thirty_d = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def outer_dish_id(self):
        return self._outer_dish_id

    @outer_dish_id.setter
    def outer_dish_id(self, value):
        self._outer_dish_id = value
    @property
    def pict(self):
        return self._pict

    @pict.setter
    def pict(self, value):
        self._pict = value
    @property
    def platform(self):
        return self._platform

    @platform.setter
    def platform(self, value):
        self._platform = value
    @property
    def price(self):
        return self._price

    @price.setter
    def price(self, value):
        self._price = value
    @property
    def quantity(self):
        return self._quantity

    @quantity.setter
    def quantity(self, value):
        self._quantity = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def sold_cnt_seven_d(self):
        return self._sold_cnt_seven_d

    @sold_cnt_seven_d.setter
    def sold_cnt_seven_d(self, value):
        self._sold_cnt_seven_d = value
    @property
    def sold_cnt_thirty_d(self):
        return self._sold_cnt_thirty_d

    @sold_cnt_thirty_d.setter
    def sold_cnt_thirty_d(self, value):
        self._sold_cnt_thirty_d = value
    @property
    def sold_reusercnt_thirty_d(self):
        return self._sold_reusercnt_thirty_d

    @sold_reusercnt_thirty_d.setter
    def sold_reusercnt_thirty_d(self, value):
        self._sold_reusercnt_thirty_d = value
    @property
    def sold_usercnt_thirty_d(self):
        return self._sold_usercnt_thirty_d

    @sold_usercnt_thirty_d.setter
    def sold_usercnt_thirty_d(self, value):
        self._sold_usercnt_thirty_d = value
    @property
    def sort_col(self):
        return self._sort_col

    @sort_col.setter
    def sort_col(self, value):
        if isinstance(value, list):
            self._sort_col = list()
            for i in value:
                self._sort_col.append(i)
    @property
    def unit(self):
        return self._unit

    @unit.setter
    def unit(self, value):
        self._unit = value


    def to_alipay_dict(self):
        params = dict()
        if self.content:
            if hasattr(self.content, 'to_alipay_dict'):
                params['content'] = self.content.to_alipay_dict()
            else:
                params['content'] = self.content
        if self.dish_type_id:
            if hasattr(self.dish_type_id, 'to_alipay_dict'):
                params['dish_type_id'] = self.dish_type_id.to_alipay_dict()
            else:
                params['dish_type_id'] = self.dish_type_id
        if self.dish_type_name:
            if hasattr(self.dish_type_name, 'to_alipay_dict'):
                params['dish_type_name'] = self.dish_type_name.to_alipay_dict()
            else:
                params['dish_type_name'] = self.dish_type_name
        if self.good_level:
            if hasattr(self.good_level, 'to_alipay_dict'):
                params['good_level'] = self.good_level.to_alipay_dict()
            else:
                params['good_level'] = self.good_level
        if self.merchant_sold_cnt_seven_d:
            if hasattr(self.merchant_sold_cnt_seven_d, 'to_alipay_dict'):
                params['merchant_sold_cnt_seven_d'] = self.merchant_sold_cnt_seven_d.to_alipay_dict()
            else:
                params['merchant_sold_cnt_seven_d'] = self.merchant_sold_cnt_seven_d
        if self.merchant_sold_cnt_thirty_d:
            if hasattr(self.merchant_sold_cnt_thirty_d, 'to_alipay_dict'):
                params['merchant_sold_cnt_thirty_d'] = self.merchant_sold_cnt_thirty_d.to_alipay_dict()
            else:
                params['merchant_sold_cnt_thirty_d'] = self.merchant_sold_cnt_thirty_d
        if self.merchant_sold_reusercnt_thirty_d:
            if hasattr(self.merchant_sold_reusercnt_thirty_d, 'to_alipay_dict'):
                params['merchant_sold_reusercnt_thirty_d'] = self.merchant_sold_reusercnt_thirty_d.to_alipay_dict()
            else:
                params['merchant_sold_reusercnt_thirty_d'] = self.merchant_sold_reusercnt_thirty_d
        if self.merchant_sold_usercnt_thirty_d:
            if hasattr(self.merchant_sold_usercnt_thirty_d, 'to_alipay_dict'):
                params['merchant_sold_usercnt_thirty_d'] = self.merchant_sold_usercnt_thirty_d.to_alipay_dict()
            else:
                params['merchant_sold_usercnt_thirty_d'] = self.merchant_sold_usercnt_thirty_d
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.outer_dish_id:
            if hasattr(self.outer_dish_id, 'to_alipay_dict'):
                params['outer_dish_id'] = self.outer_dish_id.to_alipay_dict()
            else:
                params['outer_dish_id'] = self.outer_dish_id
        if self.pict:
            if hasattr(self.pict, 'to_alipay_dict'):
                params['pict'] = self.pict.to_alipay_dict()
            else:
                params['pict'] = self.pict
        if self.platform:
            if hasattr(self.platform, 'to_alipay_dict'):
                params['platform'] = self.platform.to_alipay_dict()
            else:
                params['platform'] = self.platform
        if self.price:
            if hasattr(self.price, 'to_alipay_dict'):
                params['price'] = self.price.to_alipay_dict()
            else:
                params['price'] = self.price
        if self.quantity:
            if hasattr(self.quantity, 'to_alipay_dict'):
                params['quantity'] = self.quantity.to_alipay_dict()
            else:
                params['quantity'] = self.quantity
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.sold_cnt_seven_d:
            if hasattr(self.sold_cnt_seven_d, 'to_alipay_dict'):
                params['sold_cnt_seven_d'] = self.sold_cnt_seven_d.to_alipay_dict()
            else:
                params['sold_cnt_seven_d'] = self.sold_cnt_seven_d
        if self.sold_cnt_thirty_d:
            if hasattr(self.sold_cnt_thirty_d, 'to_alipay_dict'):
                params['sold_cnt_thirty_d'] = self.sold_cnt_thirty_d.to_alipay_dict()
            else:
                params['sold_cnt_thirty_d'] = self.sold_cnt_thirty_d
        if self.sold_reusercnt_thirty_d:
            if hasattr(self.sold_reusercnt_thirty_d, 'to_alipay_dict'):
                params['sold_reusercnt_thirty_d'] = self.sold_reusercnt_thirty_d.to_alipay_dict()
            else:
                params['sold_reusercnt_thirty_d'] = self.sold_reusercnt_thirty_d
        if self.sold_usercnt_thirty_d:
            if hasattr(self.sold_usercnt_thirty_d, 'to_alipay_dict'):
                params['sold_usercnt_thirty_d'] = self.sold_usercnt_thirty_d.to_alipay_dict()
            else:
                params['sold_usercnt_thirty_d'] = self.sold_usercnt_thirty_d
        if self.sort_col:
            if isinstance(self.sort_col, list):
                for i in range(0, len(self.sort_col)):
                    element = self.sort_col[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.sort_col[i] = element.to_alipay_dict()
            if hasattr(self.sort_col, 'to_alipay_dict'):
                params['sort_col'] = self.sort_col.to_alipay_dict()
            else:
                params['sort_col'] = self.sort_col
        if self.unit:
            if hasattr(self.unit, 'to_alipay_dict'):
                params['unit'] = self.unit.to_alipay_dict()
            else:
                params['unit'] = self.unit
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = IsvShopDishModel()
        if 'content' in d:
            o.content = d['content']
        if 'dish_type_id' in d:
            o.dish_type_id = d['dish_type_id']
        if 'dish_type_name' in d:
            o.dish_type_name = d['dish_type_name']
        if 'good_level' in d:
            o.good_level = d['good_level']
        if 'merchant_sold_cnt_seven_d' in d:
            o.merchant_sold_cnt_seven_d = d['merchant_sold_cnt_seven_d']
        if 'merchant_sold_cnt_thirty_d' in d:
            o.merchant_sold_cnt_thirty_d = d['merchant_sold_cnt_thirty_d']
        if 'merchant_sold_reusercnt_thirty_d' in d:
            o.merchant_sold_reusercnt_thirty_d = d['merchant_sold_reusercnt_thirty_d']
        if 'merchant_sold_usercnt_thirty_d' in d:
            o.merchant_sold_usercnt_thirty_d = d['merchant_sold_usercnt_thirty_d']
        if 'name' in d:
            o.name = d['name']
        if 'outer_dish_id' in d:
            o.outer_dish_id = d['outer_dish_id']
        if 'pict' in d:
            o.pict = d['pict']
        if 'platform' in d:
            o.platform = d['platform']
        if 'price' in d:
            o.price = d['price']
        if 'quantity' in d:
            o.quantity = d['quantity']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'sold_cnt_seven_d' in d:
            o.sold_cnt_seven_d = d['sold_cnt_seven_d']
        if 'sold_cnt_thirty_d' in d:
            o.sold_cnt_thirty_d = d['sold_cnt_thirty_d']
        if 'sold_reusercnt_thirty_d' in d:
            o.sold_reusercnt_thirty_d = d['sold_reusercnt_thirty_d']
        if 'sold_usercnt_thirty_d' in d:
            o.sold_usercnt_thirty_d = d['sold_usercnt_thirty_d']
        if 'sort_col' in d:
            o.sort_col = d['sort_col']
        if 'unit' in d:
            o.unit = d['unit']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiItemTaobaoIndexQueryModel(object):

    def __init__(self):
        self._city_id = None
        self._ext_info = None
        self._latitude = None
        self._longitude = None
        self._scene_code = None
        self._user_id = None

    @property
    def city_id(self):
        return self._city_id

    @city_id.setter
    def city_id(self, value):
        self._city_id = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def latitude(self):
        return self._latitude

    @latitude.setter
    def latitude(self, value):
        self._latitude = value
    @property
    def longitude(self):
        return self._longitude

    @longitude.setter
    def longitude(self, value):
        self._longitude = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.city_id:
            if hasattr(self.city_id, 'to_alipay_dict'):
                params['city_id'] = self.city_id.to_alipay_dict()
            else:
                params['city_id'] = self.city_id
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.latitude:
            if hasattr(self.latitude, 'to_alipay_dict'):
                params['latitude'] = self.latitude.to_alipay_dict()
            else:
                params['latitude'] = self.latitude
        if self.longitude:
            if hasattr(self.longitude, 'to_alipay_dict'):
                params['longitude'] = self.longitude.to_alipay_dict()
            else:
                params['longitude'] = self.longitude
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiItemTaobaoIndexQueryModel()
        if 'city_id' in d:
            o.city_id = d['city_id']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'latitude' in d:
            o.latitude = d['latitude']
        if 'longitude' in d:
            o.longitude = d['longitude']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AnswerModel import AnswerModel


class UserSubmitModel(object):

    def __init__(self):
        self._answers = None
        self._gmt_submit = None
        self._job_id = None
        self._referrer = None
        self._score = None
        self._snapshot_id = None
        self._submit_id = None
        self._user_id = None
        self._user_type = None

    @property
    def answers(self):
        return self._answers

    @answers.setter
    def answers(self, value):
        if isinstance(value, list):
            self._answers = list()
            for i in value:
                if isinstance(i, AnswerModel):
                    self._answers.append(i)
                else:
                    self._answers.append(AnswerModel.from_alipay_dict(i))
    @property
    def gmt_submit(self):
        return self._gmt_submit

    @gmt_submit.setter
    def gmt_submit(self, value):
        self._gmt_submit = value
    @property
    def job_id(self):
        return self._job_id

    @job_id.setter
    def job_id(self, value):
        self._job_id = value
    @property
    def referrer(self):
        return self._referrer

    @referrer.setter
    def referrer(self, value):
        self._referrer = value
    @property
    def score(self):
        return self._score

    @score.setter
    def score(self, value):
        self._score = value
    @property
    def snapshot_id(self):
        return self._snapshot_id

    @snapshot_id.setter
    def snapshot_id(self, value):
        self._snapshot_id = value
    @property
    def submit_id(self):
        return self._submit_id

    @submit_id.setter
    def submit_id(self, value):
        self._submit_id = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value
    @property
    def user_type(self):
        return self._user_type

    @user_type.setter
    def user_type(self, value):
        self._user_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.answers:
            if isinstance(self.answers, list):
                for i in range(0, len(self.answers)):
                    element = self.answers[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.answers[i] = element.to_alipay_dict()
            if hasattr(self.answers, 'to_alipay_dict'):
                params['answers'] = self.answers.to_alipay_dict()
            else:
                params['answers'] = self.answers
        if self.gmt_submit:
            if hasattr(self.gmt_submit, 'to_alipay_dict'):
                params['gmt_submit'] = self.gmt_submit.to_alipay_dict()
            else:
                params['gmt_submit'] = self.gmt_submit
        if self.job_id:
            if hasattr(self.job_id, 'to_alipay_dict'):
                params['job_id'] = self.job_id.to_alipay_dict()
            else:
                params['job_id'] = self.job_id
        if self.referrer:
            if hasattr(self.referrer, 'to_alipay_dict'):
                params['referrer'] = self.referrer.to_alipay_dict()
            else:
                params['referrer'] = self.referrer
        if self.score:
            if hasattr(self.score, 'to_alipay_dict'):
                params['score'] = self.score.to_alipay_dict()
            else:
                params['score'] = self.score
        if self.snapshot_id:
            if hasattr(self.snapshot_id, 'to_alipay_dict'):
                params['snapshot_id'] = self.snapshot_id.to_alipay_dict()
            else:
                params['snapshot_id'] = self.snapshot_id
        if self.submit_id:
            if hasattr(self.submit_id, 'to_alipay_dict'):
                params['submit_id'] = self.submit_id.to_alipay_dict()
            else:
                params['submit_id'] = self.submit_id
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        if self.user_type:
            if hasattr(self.user_type, 'to_alipay_dict'):
                params['user_type'] = self.user_type.to_alipay_dict()
            else:
                params['user_type'] = self.user_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = UserSubmitModel()
        if 'answers' in d:
            o.answers = d['answers']
        if 'gmt_submit' in d:
            o.gmt_submit = d['gmt_submit']
        if 'job_id' in d:
            o.job_id = d['job_id']
        if 'referrer' in d:
            o.referrer = d['referrer']
        if 'score' in d:
            o.score = d['score']
        if 'snapshot_id' in d:
            o.snapshot_id = d['snapshot_id']
        if 'submit_id' in d:
            o.submit_id = d['submit_id']
        if 'user_id' in d:
            o.user_id = d['user_id']
        if 'user_type' in d:
            o.user_type = d['user_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ManagerVO(object):

    def __init__(self):
        self._manager_name = None
        self._manager_position = None

    @property
    def manager_name(self):
        return self._manager_name

    @manager_name.setter
    def manager_name(self, value):
        self._manager_name = value
    @property
    def manager_position(self):
        return self._manager_position

    @manager_position.setter
    def manager_position(self, value):
        self._manager_position = value


    def to_alipay_dict(self):
        params = dict()
        if self.manager_name:
            if hasattr(self.manager_name, 'to_alipay_dict'):
                params['manager_name'] = self.manager_name.to_alipay_dict()
            else:
                params['manager_name'] = self.manager_name
        if self.manager_position:
            if hasattr(self.manager_position, 'to_alipay_dict'):
                params['manager_position'] = self.manager_position.to_alipay_dict()
            else:
                params['manager_position'] = self.manager_position
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ManagerVO()
        if 'manager_name' in d:
            o.manager_name = d['manager_name']
        if 'manager_position' in d:
            o.manager_position = d['manager_position']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceDataLogdataSyncModel(object):

    def __init__(self):
        self._log = None
        self._namespace = None

    @property
    def log(self):
        return self._log

    @log.setter
    def log(self, value):
        self._log = value
    @property
    def namespace(self):
        return self._namespace

    @namespace.setter
    def namespace(self, value):
        self._namespace = value


    def to_alipay_dict(self):
        params = dict()
        if self.log:
            if hasattr(self.log, 'to_alipay_dict'):
                params['log'] = self.log.to_alipay_dict()
            else:
                params['log'] = self.log
        if self.namespace:
            if hasattr(self.namespace, 'to_alipay_dict'):
                params['namespace'] = self.namespace.to_alipay_dict()
            else:
                params['namespace'] = self.namespace
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceDataLogdataSyncModel()
        if 'log' in d:
            o.log = d['log']
        if 'namespace' in d:
            o.namespace = d['namespace']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ReferenceId import ReferenceId


class AnttechBlockchainDefinSaasAgreementQueryModel(object):

    def __init__(self):
        self._out_member_id = None
        self._platform_member_id = None

    @property
    def out_member_id(self):
        return self._out_member_id

    @out_member_id.setter
    def out_member_id(self, value):
        if isinstance(value, ReferenceId):
            self._out_member_id = value
        else:
            self._out_member_id = ReferenceId.from_alipay_dict(value)
    @property
    def platform_member_id(self):
        return self._platform_member_id

    @platform_member_id.setter
    def platform_member_id(self, value):
        self._platform_member_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.out_member_id:
            if hasattr(self.out_member_id, 'to_alipay_dict'):
                params['out_member_id'] = self.out_member_id.to_alipay_dict()
            else:
                params['out_member_id'] = self.out_member_id
        if self.platform_member_id:
            if hasattr(self.platform_member_id, 'to_alipay_dict'):
                params['platform_member_id'] = self.platform_member_id.to_alipay_dict()
            else:
                params['platform_member_id'] = self.platform_member_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AnttechBlockchainDefinSaasAgreementQueryModel()
        if 'out_member_id' in d:
            o.out_member_id = d['out_member_id']
        if 'platform_member_id' in d:
            o.platform_member_id = d['platform_member_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.SignTaskResult import SignTaskResult


class AlipaySecurityProdSignatureTaskApplyResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySecurityProdSignatureTaskApplyResponse, self).__init__()
        self._order_id = None
        self._task_list = None

    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def task_list(self):
        return self._task_list

    @task_list.setter
    def task_list(self, value):
        if isinstance(value, list):
            self._task_list = list()
            for i in value:
                if isinstance(i, SignTaskResult):
                    self._task_list.append(i)
                else:
                    self._task_list.append(SignTaskResult.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipaySecurityProdSignatureTaskApplyResponse, self).parse_response_content(response_content)
        if 'order_id' in response:
            self.order_id = response['order_id']
        if 'task_list' in response:
            self.task_list = response['task_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AmpeCategoryInfo(object):

    def __init__(self):
        self._category_desc = None
        self._category_id = None

    @property
    def category_desc(self):
        return self._category_desc

    @category_desc.setter
    def category_desc(self, value):
        self._category_desc = value
    @property
    def category_id(self):
        return self._category_id

    @category_id.setter
    def category_id(self, value):
        self._category_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.category_desc:
            if hasattr(self.category_desc, 'to_alipay_dict'):
                params['category_desc'] = self.category_desc.to_alipay_dict()
            else:
                params['category_desc'] = self.category_desc
        if self.category_id:
            if hasattr(self.category_id, 'to_alipay_dict'):
                params['category_id'] = self.category_id.to_alipay_dict()
            else:
                params['category_id'] = self.category_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AmpeCategoryInfo()
        if 'category_desc' in d:
            o.category_desc = d['category_desc']
        if 'category_id' in d:
            o.category_id = d['category_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipaySocialBaseQuestInstanceSubmitResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySocialBaseQuestInstanceSubmitResponse, self).__init__()
        self._daily_count = None
        self._mark_amount = None
        self._mark_time = None
        self._mark_tip = None

    @property
    def daily_count(self):
        return self._daily_count

    @daily_count.setter
    def daily_count(self, value):
        self._daily_count = value
    @property
    def mark_amount(self):
        return self._mark_amount

    @mark_amount.setter
    def mark_amount(self, value):
        self._mark_amount = value
    @property
    def mark_time(self):
        return self._mark_time

    @mark_time.setter
    def mark_time(self, value):
        self._mark_time = value
    @property
    def mark_tip(self):
        return self._mark_tip

    @mark_tip.setter
    def mark_tip(self, value):
        self._mark_tip = value

    def parse_response_content(self, response_content):
        response = super(AlipaySocialBaseQuestInstanceSubmitResponse, self).parse_response_content(response_content)
        if 'daily_count' in response:
            self.daily_count = response['daily_count']
        if 'mark_amount' in response:
            self.mark_amount = response['mark_amount']
        if 'mark_time' in response:
            self.mark_time = response['mark_time']
        if 'mark_tip' in response:
            self.mark_tip = response['mark_tip']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenAppYufalingsanyaowubYufalingsanyaowubQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenAppYufalingsanyaowubYufalingsanyaowubQueryResponse, self).__init__()
        self._yufaa = None

    @property
    def yufaa(self):
        return self._yufaa

    @yufaa.setter
    def yufaa(self, value):
        self._yufaa = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenAppYufalingsanyaowubYufalingsanyaowubQueryResponse, self).parse_response_content(response_content)
        if 'yufaa' in response:
            self.yufaa = response['yufaa']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class GoodsTagResult(object):

    def __init__(self):
        self._tag_code = None
        self._tag_name = None

    @property
    def tag_code(self):
        return self._tag_code

    @tag_code.setter
    def tag_code(self, value):
        self._tag_code = value
    @property
    def tag_name(self):
        return self._tag_name

    @tag_name.setter
    def tag_name(self, value):
        self._tag_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.tag_code:
            if hasattr(self.tag_code, 'to_alipay_dict'):
                params['tag_code'] = self.tag_code.to_alipay_dict()
            else:
                params['tag_code'] = self.tag_code
        if self.tag_name:
            if hasattr(self.tag_name, 'to_alipay_dict'):
                params['tag_name'] = self.tag_name.to_alipay_dict()
            else:
                params['tag_name'] = self.tag_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = GoodsTagResult()
        if 'tag_code' in d:
            o.tag_code = d['tag_code']
        if 'tag_name' in d:
            o.tag_name = d['tag_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoMycarParkingCharginginfoSyncModel(object):

    def __init__(self):
        self._car_number = None
        self._isv_url = None
        self._parking_id = None
        self._serial_no = None

    @property
    def car_number(self):
        return self._car_number

    @car_number.setter
    def car_number(self, value):
        self._car_number = value
    @property
    def isv_url(self):
        return self._isv_url

    @isv_url.setter
    def isv_url(self, value):
        self._isv_url = value
    @property
    def parking_id(self):
        return self._parking_id

    @parking_id.setter
    def parking_id(self, value):
        self._parking_id = value
    @property
    def serial_no(self):
        return self._serial_no

    @serial_no.setter
    def serial_no(self, value):
        self._serial_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.car_number:
            if hasattr(self.car_number, 'to_alipay_dict'):
                params['car_number'] = self.car_number.to_alipay_dict()
            else:
                params['car_number'] = self.car_number
        if self.isv_url:
            if hasattr(self.isv_url, 'to_alipay_dict'):
                params['isv_url'] = self.isv_url.to_alipay_dict()
            else:
                params['isv_url'] = self.isv_url
        if self.parking_id:
            if hasattr(self.parking_id, 'to_alipay_dict'):
                params['parking_id'] = self.parking_id.to_alipay_dict()
            else:
                params['parking_id'] = self.parking_id
        if self.serial_no:
            if hasattr(self.serial_no, 'to_alipay_dict'):
                params['serial_no'] = self.serial_no.to_alipay_dict()
            else:
                params['serial_no'] = self.serial_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoMycarParkingCharginginfoSyncModel()
        if 'car_number' in d:
            o.car_number = d['car_number']
        if 'isv_url' in d:
            o.isv_url = d['isv_url']
        if 'parking_id' in d:
            o.parking_id = d['parking_id']
        if 'serial_no' in d:
            o.serial_no = d['serial_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.OpenItem import OpenItem
from alipay.aop.api.domain.OpenItem import OpenItem
from alipay.aop.api.domain.OpenItem import OpenItem


class KoubeiQualityTestCloudacptItemQueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiQualityTestCloudacptItemQueryResponse, self).__init__()
        self._activity_id = None
        self._batch_id = None
        self._batch_status = None
        self._fail_list = None
        self._fail_num = None
        self._item_list = None
        self._item_num = None
        self._pass_list = None
        self._pass_num = None

    @property
    def activity_id(self):
        return self._activity_id

    @activity_id.setter
    def activity_id(self, value):
        self._activity_id = value
    @property
    def batch_id(self):
        return self._batch_id

    @batch_id.setter
    def batch_id(self, value):
        self._batch_id = value
    @property
    def batch_status(self):
        return self._batch_status

    @batch_status.setter
    def batch_status(self, value):
        self._batch_status = value
    @property
    def fail_list(self):
        return self._fail_list

    @fail_list.setter
    def fail_list(self, value):
        if isinstance(value, list):
            self._fail_list = list()
            for i in value:
                if isinstance(i, OpenItem):
                    self._fail_list.append(i)
                else:
                    self._fail_list.append(OpenItem.from_alipay_dict(i))
    @property
    def fail_num(self):
        return self._fail_num

    @fail_num.setter
    def fail_num(self, value):
        self._fail_num = value
    @property
    def item_list(self):
        return self._item_list

    @item_list.setter
    def item_list(self, value):
        if isinstance(value, list):
            self._item_list = list()
            for i in value:
                if isinstance(i, OpenItem):
                    self._item_list.append(i)
                else:
                    self._item_list.append(OpenItem.from_alipay_dict(i))
    @property
    def item_num(self):
        return self._item_num

    @item_num.setter
    def item_num(self, value):
        self._item_num = value
    @property
    def pass_list(self):
        return self._pass_list

    @pass_list.setter
    def pass_list(self, value):
        if isinstance(value, list):
            self._pass_list = list()
            for i in value:
                if isinstance(i, OpenItem):
                    self._pass_list.append(i)
                else:
                    self._pass_list.append(OpenItem.from_alipay_dict(i))
    @property
    def pass_num(self):
        return self._pass_num

    @pass_num.setter
    def pass_num(self, value):
        self._pass_num = value

    def parse_response_content(self, response_content):
        response = super(KoubeiQualityTestCloudacptItemQueryResponse, self).parse_response_content(response_content)
        if 'activity_id' in response:
            self.activity_id = response['activity_id']
        if 'batch_id' in response:
            self.batch_id = response['batch_id']
        if 'batch_status' in response:
            self.batch_status = response['batch_status']
        if 'fail_list' in response:
            self.fail_list = response['fail_list']
        if 'fail_num' in response:
            self.fail_num = response['fail_num']
        if 'item_list' in response:
            self.item_list = response['item_list']
        if 'item_num' in response:
            self.item_num = response['item_num']
        if 'pass_list' in response:
            self.pass_list = response['pass_list']
        if 'pass_num' in response:
            self.pass_num = response['pass_num']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenMiniActivityGiftQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenMiniActivityGiftQueryResponse, self).__init__()
        self._amount_cent = None
        self._ceiling_amount_cent = None
        self._end_time = None
        self._floor_amount_cent = None
        self._full_redirect_url = None
        self._mini_app_id = None
        self._pid = None
        self._remain_amount = None
        self._single_user_limit = None
        self._start_time = None
        self._status = None
        self._template_id = None
        self._template_name = None
        self._total_amount = None
        self._voucher_discount_percent = None
        self._voucher_jump_url = None
        self._voucher_name = None
        self._voucher_template_id = None
        self._voucher_type = None

    @property
    def amount_cent(self):
        return self._amount_cent

    @amount_cent.setter
    def amount_cent(self, value):
        self._amount_cent = value
    @property
    def ceiling_amount_cent(self):
        return self._ceiling_amount_cent

    @ceiling_amount_cent.setter
    def ceiling_amount_cent(self, value):
        self._ceiling_amount_cent = value
    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def floor_amount_cent(self):
        return self._floor_amount_cent

    @floor_amount_cent.setter
    def floor_amount_cent(self, value):
        self._floor_amount_cent = value
    @property
    def full_redirect_url(self):
        return self._full_redirect_url

    @full_redirect_url.setter
    def full_redirect_url(self, value):
        self._full_redirect_url = value
    @property
    def mini_app_id(self):
        return self._mini_app_id

    @mini_app_id.setter
    def mini_app_id(self, value):
        self._mini_app_id = value
    @property
    def pid(self):
        return self._pid

    @pid.setter
    def pid(self, value):
        self._pid = value
    @property
    def remain_amount(self):
        return self._remain_amount

    @remain_amount.setter
    def remain_amount(self, value):
        self._remain_amount = value
    @property
    def single_user_limit(self):
        return self._single_user_limit

    @single_user_limit.setter
    def single_user_limit(self, value):
        self._single_user_limit = value
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def template_id(self):
        return self._template_id

    @template_id.setter
    def template_id(self, value):
        self._template_id = value
    @property
    def template_name(self):
        return self._template_name

    @template_name.setter
    def template_name(self, value):
        self._template_name = value
    @property
    def total_amount(self):
        return self._total_amount

    @total_amount.setter
    def total_amount(self, value):
        self._total_amount = value
    @property
    def voucher_discount_percent(self):
        return self._voucher_discount_percent

    @voucher_discount_percent.setter
    def voucher_discount_percent(self, value):
        self._voucher_discount_percent = value
    @property
    def voucher_jump_url(self):
        return self._voucher_jump_url

    @voucher_jump_url.setter
    def voucher_jump_url(self, value):
        self._voucher_jump_url = value
    @property
    def voucher_name(self):
        return self._voucher_name

    @voucher_name.setter
    def voucher_name(self, value):
        self._voucher_name = value
    @property
    def voucher_template_id(self):
        return self._voucher_template_id

    @voucher_template_id.setter
    def voucher_template_id(self, value):
        self._voucher_template_id = value
    @property
    def voucher_type(self):
        return self._voucher_type

    @voucher_type.setter
    def voucher_type(self, value):
        self._voucher_type = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenMiniActivityGiftQueryResponse, self).parse_response_content(response_content)
        if 'amount_cent' in response:
            self.amount_cent = response['amount_cent']
        if 'ceiling_amount_cent' in response:
            self.ceiling_amount_cent = response['ceiling_amount_cent']
        if 'end_time' in response:
            self.end_time = response['end_time']
        if 'floor_amount_cent' in response:
            self.floor_amount_cent = response['floor_amount_cent']
        if 'full_redirect_url' in response:
            self.full_redirect_url = response['full_redirect_url']
        if 'mini_app_id' in response:
            self.mini_app_id = response['mini_app_id']
        if 'pid' in response:
            self.pid = response['pid']
        if 'remain_amount' in response:
            self.remain_amount = response['remain_amount']
        if 'single_user_limit' in response:
            self.single_user_limit = response['single_user_limit']
        if 'start_time' in response:
            self.start_time = response['start_time']
        if 'status' in response:
            self.status = response['status']
        if 'template_id' in response:
            self.template_id = response['template_id']
        if 'template_name' in response:
            self.template_name = response['template_name']
        if 'total_amount' in response:
            self.total_amount = response['total_amount']
        if 'voucher_discount_percent' in response:
            self.voucher_discount_percent = response['voucher_discount_percent']
        if 'voucher_jump_url' in response:
            self.voucher_jump_url = response['voucher_jump_url']
        if 'voucher_name' in response:
            self.voucher_name = response['voucher_name']
        if 'voucher_template_id' in response:
            self.voucher_template_id = response['voucher_template_id']
        if 'voucher_type' in response:
            self.voucher_type = response['voucher_type']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ApUserMailInfoOpenApiResponse import ApUserMailInfoOpenApiResponse


class ApUserInvoiceInfoOpenApiResponse(object):

    def __init__(self):
        self._accept_electronic = None
        self._address = None
        self._auto = None
        self._bank_account = None
        self._bank_name = None
        self._business_licence_url = None
        self._creator = None
        self._gmt_create = None
        self._gmt_modified = None
        self._hold = None
        self._id = None
        self._ip_id = None
        self._ip_role_id = None
        self._last_modifier = None
        self._open_account_permit_url = None
        self._other_qualification_url = None
        self._status = None
        self._task_date = None
        self._tax_no = None
        self._tax_payer_qualification = None
        self._tax_qualification_url = None
        self._tax_reg_cert_url = None
        self._taxpayer_quali_valid = None
        self._telephone = None
        self._title = None
        self._tnt_inst_id = None
        self._type = None
        self._user_mail_info_list = None

    @property
    def accept_electronic(self):
        return self._accept_electronic

    @accept_electronic.setter
    def accept_electronic(self, value):
        self._accept_electronic = value
    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def auto(self):
        return self._auto

    @auto.setter
    def auto(self, value):
        self._auto = value
    @property
    def bank_account(self):
        return self._bank_account

    @bank_account.setter
    def bank_account(self, value):
        self._bank_account = value
    @property
    def bank_name(self):
        return self._bank_name

    @bank_name.setter
    def bank_name(self, value):
        self._bank_name = value
    @property
    def business_licence_url(self):
        return self._business_licence_url

    @business_licence_url.setter
    def business_licence_url(self, value):
        self._business_licence_url = value
    @property
    def creator(self):
        return self._creator

    @creator.setter
    def creator(self, value):
        self._creator = value
    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def hold(self):
        return self._hold

    @hold.setter
    def hold(self, value):
        self._hold = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def ip_id(self):
        return self._ip_id

    @ip_id.setter
    def ip_id(self, value):
        self._ip_id = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value
    @property
    def last_modifier(self):
        return self._last_modifier

    @last_modifier.setter
    def last_modifier(self, value):
        self._last_modifier = value
    @property
    def open_account_permit_url(self):
        return self._open_account_permit_url

    @open_account_permit_url.setter
    def open_account_permit_url(self, value):
        self._open_account_permit_url = value
    @property
    def other_qualification_url(self):
        return self._other_qualification_url

    @other_qualification_url.setter
    def other_qualification_url(self, value):
        self._other_qualification_url = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def task_date(self):
        return self._task_date

    @task_date.setter
    def task_date(self, value):
        self._task_date = value
    @property
    def tax_no(self):
        return self._tax_no

    @tax_no.setter
    def tax_no(self, value):
        self._tax_no = value
    @property
    def tax_payer_qualification(self):
        return self._tax_payer_qualification

    @tax_payer_qualification.setter
    def tax_payer_qualification(self, value):
        self._tax_payer_qualification = value
    @property
    def tax_qualification_url(self):
        return self._tax_qualification_url

    @tax_qualification_url.setter
    def tax_qualification_url(self, value):
        self._tax_qualification_url = value
    @property
    def tax_reg_cert_url(self):
        return self._tax_reg_cert_url

    @tax_reg_cert_url.setter
    def tax_reg_cert_url(self, value):
        self._tax_reg_cert_url = value
    @property
    def taxpayer_quali_valid(self):
        return self._taxpayer_quali_valid

    @taxpayer_quali_valid.setter
    def taxpayer_quali_valid(self, value):
        self._taxpayer_quali_valid = value
    @property
    def telephone(self):
        return self._telephone

    @telephone.setter
    def telephone(self, value):
        self._telephone = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value
    @property
    def tnt_inst_id(self):
        return self._tnt_inst_id

    @tnt_inst_id.setter
    def tnt_inst_id(self, value):
        self._tnt_inst_id = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value
    @property
    def user_mail_info_list(self):
        return self._user_mail_info_list

    @user_mail_info_list.setter
    def user_mail_info_list(self, value):
        if isinstance(value, list):
            self._user_mail_info_list = list()
            for i in value:
                if isinstance(i, ApUserMailInfoOpenApiResponse):
                    self._user_mail_info_list.append(i)
                else:
                    self._user_mail_info_list.append(ApUserMailInfoOpenApiResponse.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.accept_electronic:
            if hasattr(self.accept_electronic, 'to_alipay_dict'):
                params['accept_electronic'] = self.accept_electronic.to_alipay_dict()
            else:
                params['accept_electronic'] = self.accept_electronic
        if self.address:
            if hasattr(self.address, 'to_alipay_dict'):
                params['address'] = self.address.to_alipay_dict()
            else:
                params['address'] = self.address
        if self.auto:
            if hasattr(self.auto, 'to_alipay_dict'):
                params['auto'] = self.auto.to_alipay_dict()
            else:
                params['auto'] = self.auto
        if self.bank_account:
            if hasattr(self.bank_account, 'to_alipay_dict'):
                params['bank_account'] = self.bank_account.to_alipay_dict()
            else:
                params['bank_account'] = self.bank_account
        if self.bank_name:
            if hasattr(self.bank_name, 'to_alipay_dict'):
                params['bank_name'] = self.bank_name.to_alipay_dict()
            else:
                params['bank_name'] = self.bank_name
        if self.business_licence_url:
            if hasattr(self.business_licence_url, 'to_alipay_dict'):
                params['business_licence_url'] = self.business_licence_url.to_alipay_dict()
            else:
                params['business_licence_url'] = self.business_licence_url
        if self.creator:
            if hasattr(self.creator, 'to_alipay_dict'):
                params['creator'] = self.creator.to_alipay_dict()
            else:
                params['creator'] = self.creator
        if self.gmt_create:
            if hasattr(self.gmt_create, 'to_alipay_dict'):
                params['gmt_create'] = self.gmt_create.to_alipay_dict()
            else:
                params['gmt_create'] = self.gmt_create
        if self.gmt_modified:
            if hasattr(self.gmt_modified, 'to_alipay_dict'):
                params['gmt_modified'] = self.gmt_modified.to_alipay_dict()
            else:
                params['gmt_modified'] = self.gmt_modified
        if self.hold:
            if hasattr(self.hold, 'to_alipay_dict'):
                params['hold'] = self.hold.to_alipay_dict()
            else:
                params['hold'] = self.hold
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.ip_id:
            if hasattr(self.ip_id, 'to_alipay_dict'):
                params['ip_id'] = self.ip_id.to_alipay_dict()
            else:
                params['ip_id'] = self.ip_id
        if self.ip_role_id:
            if hasattr(self.ip_role_id, 'to_alipay_dict'):
                params['ip_role_id'] = self.ip_role_id.to_alipay_dict()
            else:
                params['ip_role_id'] = self.ip_role_id
        if self.last_modifier:
            if hasattr(self.last_modifier, 'to_alipay_dict'):
                params['last_modifier'] = self.last_modifier.to_alipay_dict()
            else:
                params['last_modifier'] = self.last_modifier
        if self.open_account_permit_url:
            if hasattr(self.open_account_permit_url, 'to_alipay_dict'):
                params['open_account_permit_url'] = self.open_account_permit_url.to_alipay_dict()
            else:
                params['open_account_permit_url'] = self.open_account_permit_url
        if self.other_qualification_url:
            if hasattr(self.other_qualification_url, 'to_alipay_dict'):
                params['other_qualification_url'] = self.other_qualification_url.to_alipay_dict()
            else:
                params['other_qualification_url'] = self.other_qualification_url
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.task_date:
            if hasattr(self.task_date, 'to_alipay_dict'):
                params['task_date'] = self.task_date.to_alipay_dict()
            else:
                params['task_date'] = self.task_date
        if self.tax_no:
            if hasattr(self.tax_no, 'to_alipay_dict'):
                params['tax_no'] = self.tax_no.to_alipay_dict()
            else:
                params['tax_no'] = self.tax_no
        if self.tax_payer_qualification:
            if hasattr(self.tax_payer_qualification, 'to_alipay_dict'):
                params['tax_payer_qualification'] = self.tax_payer_qualification.to_alipay_dict()
            else:
                params['tax_payer_qualification'] = self.tax_payer_qualification
        if self.tax_qualification_url:
            if hasattr(self.tax_qualification_url, 'to_alipay_dict'):
                params['tax_qualification_url'] = self.tax_qualification_url.to_alipay_dict()
            else:
                params['tax_qualification_url'] = self.tax_qualification_url
        if self.tax_reg_cert_url:
            if hasattr(self.tax_reg_cert_url, 'to_alipay_dict'):
                params['tax_reg_cert_url'] = self.tax_reg_cert_url.to_alipay_dict()
            else:
                params['tax_reg_cert_url'] = self.tax_reg_cert_url
        if self.taxpayer_quali_valid:
            if hasattr(self.taxpayer_quali_valid, 'to_alipay_dict'):
                params['taxpayer_quali_valid'] = self.taxpayer_quali_valid.to_alipay_dict()
            else:
                params['taxpayer_quali_valid'] = self.taxpayer_quali_valid
        if self.telephone:
            if hasattr(self.telephone, 'to_alipay_dict'):
                params['telephone'] = self.telephone.to_alipay_dict()
            else:
                params['telephone'] = self.telephone
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        if self.tnt_inst_id:
            if hasattr(self.tnt_inst_id, 'to_alipay_dict'):
                params['tnt_inst_id'] = self.tnt_inst_id.to_alipay_dict()
            else:
                params['tnt_inst_id'] = self.tnt_inst_id
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        if self.user_mail_info_list:
            if isinstance(self.user_mail_info_list, list):
                for i in range(0, len(self.user_mail_info_list)):
                    element = self.user_mail_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.user_mail_info_list[i] = element.to_alipay_dict()
            if hasattr(self.user_mail_info_list, 'to_alipay_dict'):
                params['user_mail_info_list'] = self.user_mail_info_list.to_alipay_dict()
            else:
                params['user_mail_info_list'] = self.user_mail_info_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ApUserInvoiceInfoOpenApiResponse()
        if 'accept_electronic' in d:
            o.accept_electronic = d['accept_electronic']
        if 'address' in d:
            o.address = d['address']
        if 'auto' in d:
            o.auto = d['auto']
        if 'bank_account' in d:
            o.bank_account = d['bank_account']
        if 'bank_name' in d:
            o.bank_name = d['bank_name']
        if 'business_licence_url' in d:
            o.business_licence_url = d['business_licence_url']
        if 'creator' in d:
            o.creator = d['creator']
        if 'gmt_create' in d:
            o.gmt_create = d['gmt_create']
        if 'gmt_modified' in d:
            o.gmt_modified = d['gmt_modified']
        if 'hold' in d:
            o.hold = d['hold']
        if 'id' in d:
            o.id = d['id']
        if 'ip_id' in d:
            o.ip_id = d['ip_id']
        if 'ip_role_id' in d:
            o.ip_role_id = d['ip_role_id']
        if 'last_modifier' in d:
            o.last_modifier = d['last_modifier']
        if 'open_account_permit_url' in d:
            o.open_account_permit_url = d['open_account_permit_url']
        if 'other_qualification_url' in d:
            o.other_qualification_url = d['other_qualification_url']
        if 'status' in d:
            o.status = d['status']
        if 'task_date' in d:
            o.task_date = d['task_date']
        if 'tax_no' in d:
            o.tax_no = d['tax_no']
        if 'tax_payer_qualification' in d:
            o.tax_payer_qualification = d['tax_payer_qualification']
        if 'tax_qualification_url' in d:
            o.tax_qualification_url = d['tax_qualification_url']
        if 'tax_reg_cert_url' in d:
            o.tax_reg_cert_url = d['tax_reg_cert_url']
        if 'taxpayer_quali_valid' in d:
            o.taxpayer_quali_valid = d['taxpayer_quali_valid']
        if 'telephone' in d:
            o.telephone = d['telephone']
        if 'title' in d:
            o.title = d['title']
        if 'tnt_inst_id' in d:
            o.tnt_inst_id = d['tnt_inst_id']
        if 'type' in d:
            o.type = d['type']
        if 'user_mail_info_list' in d:
            o.user_mail_info_list = d['user_mail_info_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AntMerchantExpandIndirectTransferModel(object):

    def __init__(self):
        self._external_id = None
        self._sub_merchant_id = None
        self._transfer_target_id = None

    @property
    def external_id(self):
        return self._external_id

    @external_id.setter
    def external_id(self, value):
        self._external_id = value
    @property
    def sub_merchant_id(self):
        return self._sub_merchant_id

    @sub_merchant_id.setter
    def sub_merchant_id(self, value):
        self._sub_merchant_id = value
    @property
    def transfer_target_id(self):
        return self._transfer_target_id

    @transfer_target_id.setter
    def transfer_target_id(self, value):
        self._transfer_target_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.external_id:
            if hasattr(self.external_id, 'to_alipay_dict'):
                params['external_id'] = self.external_id.to_alipay_dict()
            else:
                params['external_id'] = self.external_id
        if self.sub_merchant_id:
            if hasattr(self.sub_merchant_id, 'to_alipay_dict'):
                params['sub_merchant_id'] = self.sub_merchant_id.to_alipay_dict()
            else:
                params['sub_merchant_id'] = self.sub_merchant_id
        if self.transfer_target_id:
            if hasattr(self.transfer_target_id, 'to_alipay_dict'):
                params['transfer_target_id'] = self.transfer_target_id.to_alipay_dict()
            else:
                params['transfer_target_id'] = self.transfer_target_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntMerchantExpandIndirectTransferModel()
        if 'external_id' in d:
            o.external_id = d['external_id']
        if 'sub_merchant_id' in d:
            o.sub_merchant_id = d['sub_merchant_id']
        if 'transfer_target_id' in d:
            o.transfer_target_id = d['transfer_target_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEcoMycarParkingOrderPayResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEcoMycarParkingOrderPayResponse, self).__init__()
        self._advance_amount = None
        self._alipay_repayment_url = None
        self._fund_bill_list = None
        self._gmt_payment = None
        self._out_trade_no = None
        self._total_fee = None
        self._trade_no = None
        self._user_id = None

    @property
    def advance_amount(self):
        return self._advance_amount

    @advance_amount.setter
    def advance_amount(self, value):
        self._advance_amount = value
    @property
    def alipay_repayment_url(self):
        return self._alipay_repayment_url

    @alipay_repayment_url.setter
    def alipay_repayment_url(self, value):
        self._alipay_repayment_url = value
    @property
    def fund_bill_list(self):
        return self._fund_bill_list

    @fund_bill_list.setter
    def fund_bill_list(self, value):
        self._fund_bill_list = value
    @property
    def gmt_payment(self):
        return self._gmt_payment

    @gmt_payment.setter
    def gmt_payment(self, value):
        self._gmt_payment = value
    @property
    def out_trade_no(self):
        return self._out_trade_no

    @out_trade_no.setter
    def out_trade_no(self, value):
        self._out_trade_no = value
    @property
    def total_fee(self):
        return self._total_fee

    @total_fee.setter
    def total_fee(self, value):
        self._total_fee = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayEcoMycarParkingOrderPayResponse, self).parse_response_content(response_content)
        if 'advance_amount' in response:
            self.advance_amount = response['advance_amount']
        if 'alipay_repayment_url' in response:
            self.alipay_repayment_url = response['alipay_repayment_url']
        if 'fund_bill_list' in response:
            self.fund_bill_list = response['fund_bill_list']
        if 'gmt_payment' in response:
            self.gmt_payment = response['gmt_payment']
        if 'out_trade_no' in response:
            self.out_trade_no = response['out_trade_no']
        if 'total_fee' in response:
            self.total_fee = response['total_fee']
        if 'trade_no' in response:
            self.trade_no = response['trade_no']
        if 'user_id' in response:
            self.user_id = response['user_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEbppInstserviceIdentityInitializeResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppInstserviceIdentityInitializeResponse, self).__init__()
        self._extend_field = None
        self._verify_id = None

    @property
    def extend_field(self):
        return self._extend_field

    @extend_field.setter
    def extend_field(self, value):
        self._extend_field = value
    @property
    def verify_id(self):
        return self._verify_id

    @verify_id.setter
    def verify_id(self, value):
        self._verify_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppInstserviceIdentityInitializeResponse, self).parse_response_content(response_content)
        if 'extend_field' in response:
            self.extend_field = response['extend_field']
        if 'verify_id' in response:
            self.verify_id = response['verify_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenOperationBizfeeAftechSubscribeModel(object):

    def __init__(self):
        self._app_name = None
        self._ar_no = None
        self._customer = None
        self._fee_amount = None
        self._fee_currency = None
        self._gmt_begin = None
        self._gmt_end = None
        self._gmt_service = None
        self._inst_code = None
        self._out_biz_no = None
        self._pkg_type = None
        self._product_code = None
        self._properties = None
        self._rel_order_no = None
        self._service_amount = None
        self._tnt_inst_id = None

    @property
    def app_name(self):
        return self._app_name

    @app_name.setter
    def app_name(self, value):
        self._app_name = value
    @property
    def ar_no(self):
        return self._ar_no

    @ar_no.setter
    def ar_no(self, value):
        self._ar_no = value
    @property
    def customer(self):
        return self._customer

    @customer.setter
    def customer(self, value):
        self._customer = value
    @property
    def fee_amount(self):
        return self._fee_amount

    @fee_amount.setter
    def fee_amount(self, value):
        self._fee_amount = value
    @property
    def fee_currency(self):
        return self._fee_currency

    @fee_currency.setter
    def fee_currency(self, value):
        self._fee_currency = value
    @property
    def gmt_begin(self):
        return self._gmt_begin

    @gmt_begin.setter
    def gmt_begin(self, value):
        self._gmt_begin = value
    @property
    def gmt_end(self):
        return self._gmt_end

    @gmt_end.setter
    def gmt_end(self, value):
        self._gmt_end = value
    @property
    def gmt_service(self):
        return self._gmt_service

    @gmt_service.setter
    def gmt_service(self, value):
        self._gmt_service = value
    @property
    def inst_code(self):
        return self._inst_code

    @inst_code.setter
    def inst_code(self, value):
        self._inst_code = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def pkg_type(self):
        return self._pkg_type

    @pkg_type.setter
    def pkg_type(self, value):
        self._pkg_type = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def properties(self):
        return self._properties

    @properties.setter
    def properties(self, value):
        self._properties = value
    @property
    def rel_order_no(self):
        return self._rel_order_no

    @rel_order_no.setter
    def rel_order_no(self, value):
        self._rel_order_no = value
    @property
    def service_amount(self):
        return self._service_amount

    @service_amount.setter
    def service_amount(self, value):
        self._service_amount = value
    @property
    def tnt_inst_id(self):
        return self._tnt_inst_id

    @tnt_inst_id.setter
    def tnt_inst_id(self, value):
        self._tnt_inst_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_name:
            if hasattr(self.app_name, 'to_alipay_dict'):
                params['app_name'] = self.app_name.to_alipay_dict()
            else:
                params['app_name'] = self.app_name
        if self.ar_no:
            if hasattr(self.ar_no, 'to_alipay_dict'):
                params['ar_no'] = self.ar_no.to_alipay_dict()
            else:
                params['ar_no'] = self.ar_no
        if self.customer:
            if hasattr(self.customer, 'to_alipay_dict'):
                params['customer'] = self.customer.to_alipay_dict()
            else:
                params['customer'] = self.customer
        if self.fee_amount:
            if hasattr(self.fee_amount, 'to_alipay_dict'):
                params['fee_amount'] = self.fee_amount.to_alipay_dict()
            else:
                params['fee_amount'] = self.fee_amount
        if self.fee_currency:
            if hasattr(self.fee_currency, 'to_alipay_dict'):
                params['fee_currency'] = self.fee_currency.to_alipay_dict()
            else:
                params['fee_currency'] = self.fee_currency
        if self.gmt_begin:
            if hasattr(self.gmt_begin, 'to_alipay_dict'):
                params['gmt_begin'] = self.gmt_begin.to_alipay_dict()
            else:
                params['gmt_begin'] = self.gmt_begin
        if self.gmt_end:
            if hasattr(self.gmt_end, 'to_alipay_dict'):
                params['gmt_end'] = self.gmt_end.to_alipay_dict()
            else:
                params['gmt_end'] = self.gmt_end
        if self.gmt_service:
            if hasattr(self.gmt_service, 'to_alipay_dict'):
                params['gmt_service'] = self.gmt_service.to_alipay_dict()
            else:
                params['gmt_service'] = self.gmt_service
        if self.inst_code:
            if hasattr(self.inst_code, 'to_alipay_dict'):
                params['inst_code'] = self.inst_code.to_alipay_dict()
            else:
                params['inst_code'] = self.inst_code
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.pkg_type:
            if hasattr(self.pkg_type, 'to_alipay_dict'):
                params['pkg_type'] = self.pkg_type.to_alipay_dict()
            else:
                params['pkg_type'] = self.pkg_type
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.properties:
            if hasattr(self.properties, 'to_alipay_dict'):
                params['properties'] = self.properties.to_alipay_dict()
            else:
                params['properties'] = self.properties
        if self.rel_order_no:
            if hasattr(self.rel_order_no, 'to_alipay_dict'):
                params['rel_order_no'] = self.rel_order_no.to_alipay_dict()
            else:
                params['rel_order_no'] = self.rel_order_no
        if self.service_amount:
            if hasattr(self.service_amount, 'to_alipay_dict'):
                params['service_amount'] = self.service_amount.to_alipay_dict()
            else:
                params['service_amount'] = self.service_amount
        if self.tnt_inst_id:
            if hasattr(self.tnt_inst_id, 'to_alipay_dict'):
                params['tnt_inst_id'] = self.tnt_inst_id.to_alipay_dict()
            else:
                params['tnt_inst_id'] = self.tnt_inst_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenOperationBizfeeAftechSubscribeModel()
        if 'app_name' in d:
            o.app_name = d['app_name']
        if 'ar_no' in d:
            o.ar_no = d['ar_no']
        if 'customer' in d:
            o.customer = d['customer']
        if 'fee_amount' in d:
            o.fee_amount = d['fee_amount']
        if 'fee_currency' in d:
            o.fee_currency = d['fee_currency']
        if 'gmt_begin' in d:
            o.gmt_begin = d['gmt_begin']
        if 'gmt_end' in d:
            o.gmt_end = d['gmt_end']
        if 'gmt_service' in d:
            o.gmt_service = d['gmt_service']
        if 'inst_code' in d:
            o.inst_code = d['inst_code']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'pkg_type' in d:
            o.pkg_type = d['pkg_type']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'properties' in d:
            o.properties = d['properties']
        if 'rel_order_no' in d:
            o.rel_order_no = d['rel_order_no']
        if 'service_amount' in d:
            o.service_amount = d['service_amount']
        if 'tnt_inst_id' in d:
            o.tnt_inst_id = d['tnt_inst_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ScheduleInfo(object):

    def __init__(self):
        self._bitmap = None
        self._date = None

    @property
    def bitmap(self):
        return self._bitmap

    @bitmap.setter
    def bitmap(self, value):
        self._bitmap = value
    @property
    def date(self):
        return self._date

    @date.setter
    def date(self, value):
        self._date = value


    def to_alipay_dict(self):
        params = dict()
        if self.bitmap:
            if hasattr(self.bitmap, 'to_alipay_dict'):
                params['bitmap'] = self.bitmap.to_alipay_dict()
            else:
                params['bitmap'] = self.bitmap
        if self.date:
            if hasattr(self.date, 'to_alipay_dict'):
                params['date'] = self.date.to_alipay_dict()
            else:
                params['date'] = self.date
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ScheduleInfo()
        if 'bitmap' in d:
            o.bitmap = d['bitmap']
        if 'date' in d:
            o.date = d['date']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class KoubeiMarketingCampaignActivityModifyResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiMarketingCampaignActivityModifyResponse, self).__init__()
        self._audit_status = None
        self._camp_status = None

    @property
    def audit_status(self):
        return self._audit_status

    @audit_status.setter
    def audit_status(self, value):
        self._audit_status = value
    @property
    def camp_status(self):
        return self._camp_status

    @camp_status.setter
    def camp_status(self, value):
        self._camp_status = value

    def parse_response_content(self, response_content):
        response = super(KoubeiMarketingCampaignActivityModifyResponse, self).parse_response_content(response_content)
        if 'audit_status' in response:
            self.audit_status = response['audit_status']
        if 'camp_status' in response:
            self.camp_status = response['camp_status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KeyanColumn(object):

    def __init__(self):
        self._password = None

    @property
    def password(self):
        return self._password

    @password.setter
    def password(self, value):
        self._password = value


    def to_alipay_dict(self):
        params = dict()
        if self.password:
            if hasattr(self.password, 'to_alipay_dict'):
                params['password'] = self.password.to_alipay_dict()
            else:
                params['password'] = self.password
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KeyanColumn()
        if 'password' in d:
            o.password = d['password']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MapTypeParam import MapTypeParam
from alipay.aop.api.domain.PayContractItemDTO import PayContractItemDTO


class PayContractDTO(object):

    def __init__(self):
        self._account_ext_info = None
        self._account_name = None
        self._account_no = None
        self._account_type = None
        self._agreement_no = None
        self._agreement_source = None
        self._biz_pdcode = None
        self._branch_name = None
        self._company_code = None
        self._currency = None
        self._idempotent_no = None
        self._ip_role_id = None
        self._ip_role_source = None
        self._pay_contract_items = None
        self._payment_type = None
        self._pd_code = None
        self._sales_product_code = None
        self._source = None

    @property
    def account_ext_info(self):
        return self._account_ext_info

    @account_ext_info.setter
    def account_ext_info(self, value):
        if isinstance(value, MapTypeParam):
            self._account_ext_info = value
        else:
            self._account_ext_info = MapTypeParam.from_alipay_dict(value)
    @property
    def account_name(self):
        return self._account_name

    @account_name.setter
    def account_name(self, value):
        self._account_name = value
    @property
    def account_no(self):
        return self._account_no

    @account_no.setter
    def account_no(self, value):
        self._account_no = value
    @property
    def account_type(self):
        return self._account_type

    @account_type.setter
    def account_type(self, value):
        self._account_type = value
    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def agreement_source(self):
        return self._agreement_source

    @agreement_source.setter
    def agreement_source(self, value):
        self._agreement_source = value
    @property
    def biz_pdcode(self):
        return self._biz_pdcode

    @biz_pdcode.setter
    def biz_pdcode(self, value):
        self._biz_pdcode = value
    @property
    def branch_name(self):
        return self._branch_name

    @branch_name.setter
    def branch_name(self, value):
        self._branch_name = value
    @property
    def company_code(self):
        return self._company_code

    @company_code.setter
    def company_code(self, value):
        self._company_code = value
    @property
    def currency(self):
        return self._currency

    @currency.setter
    def currency(self, value):
        self._currency = value
    @property
    def idempotent_no(self):
        return self._idempotent_no

    @idempotent_no.setter
    def idempotent_no(self, value):
        self._idempotent_no = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value
    @property
    def ip_role_source(self):
        return self._ip_role_source

    @ip_role_source.setter
    def ip_role_source(self, value):
        self._ip_role_source = value
    @property
    def pay_contract_items(self):
        return self._pay_contract_items

    @pay_contract_items.setter
    def pay_contract_items(self, value):
        if isinstance(value, list):
            self._pay_contract_items = list()
            for i in value:
                if isinstance(i, PayContractItemDTO):
                    self._pay_contract_items.append(i)
                else:
                    self._pay_contract_items.append(PayContractItemDTO.from_alipay_dict(i))
    @property
    def payment_type(self):
        return self._payment_type

    @payment_type.setter
    def payment_type(self, value):
        self._payment_type = value
    @property
    def pd_code(self):
        return self._pd_code

    @pd_code.setter
    def pd_code(self, value):
        self._pd_code = value
    @property
    def sales_product_code(self):
        return self._sales_product_code

    @sales_product_code.setter
    def sales_product_code(self, value):
        self._sales_product_code = value
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_ext_info:
            if hasattr(self.account_ext_info, 'to_alipay_dict'):
                params['account_ext_info'] = self.account_ext_info.to_alipay_dict()
            else:
                params['account_ext_info'] = self.account_ext_info
        if self.account_name:
            if hasattr(self.account_name, 'to_alipay_dict'):
                params['account_name'] = self.account_name.to_alipay_dict()
            else:
                params['account_name'] = self.account_name
        if self.account_no:
            if hasattr(self.account_no, 'to_alipay_dict'):
                params['account_no'] = self.account_no.to_alipay_dict()
            else:
                params['account_no'] = self.account_no
        if self.account_type:
            if hasattr(self.account_type, 'to_alipay_dict'):
                params['account_type'] = self.account_type.to_alipay_dict()
            else:
                params['account_type'] = self.account_type
        if self.agreement_no:
            if hasattr(self.agreement_no, 'to_alipay_dict'):
                params['agreement_no'] = self.agreement_no.to_alipay_dict()
            else:
                params['agreement_no'] = self.agreement_no
        if self.agreement_source:
            if hasattr(self.agreement_source, 'to_alipay_dict'):
                params['agreement_source'] = self.agreement_source.to_alipay_dict()
            else:
                params['agreement_source'] = self.agreement_source
        if self.biz_pdcode:
            if hasattr(self.biz_pdcode, 'to_alipay_dict'):
                params['biz_pdcode'] = self.biz_pdcode.to_alipay_dict()
            else:
                params['biz_pdcode'] = self.biz_pdcode
        if self.branch_name:
            if hasattr(self.branch_name, 'to_alipay_dict'):
                params['branch_name'] = self.branch_name.to_alipay_dict()
            else:
                params['branch_name'] = self.branch_name
        if self.company_code:
            if hasattr(self.company_code, 'to_alipay_dict'):
                params['company_code'] = self.company_code.to_alipay_dict()
            else:
                params['company_code'] = self.company_code
        if self.currency:
            if hasattr(self.currency, 'to_alipay_dict'):
                params['currency'] = self.currency.to_alipay_dict()
            else:
                params['currency'] = self.currency
        if self.idempotent_no:
            if hasattr(self.idempotent_no, 'to_alipay_dict'):
                params['idempotent_no'] = self.idempotent_no.to_alipay_dict()
            else:
                params['idempotent_no'] = self.idempotent_no
        if self.ip_role_id:
            if hasattr(self.ip_role_id, 'to_alipay_dict'):
                params['ip_role_id'] = self.ip_role_id.to_alipay_dict()
            else:
                params['ip_role_id'] = self.ip_role_id
        if self.ip_role_source:
            if hasattr(self.ip_role_source, 'to_alipay_dict'):
                params['ip_role_source'] = self.ip_role_source.to_alipay_dict()
            else:
                params['ip_role_source'] = self.ip_role_source
        if self.pay_contract_items:
            if isinstance(self.pay_contract_items, list):
                for i in range(0, len(self.pay_contract_items)):
                    element = self.pay_contract_items[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.pay_contract_items[i] = element.to_alipay_dict()
            if hasattr(self.pay_contract_items, 'to_alipay_dict'):
                params['pay_contract_items'] = self.pay_contract_items.to_alipay_dict()
            else:
                params['pay_contract_items'] = self.pay_contract_items
        if self.payment_type:
            if hasattr(self.payment_type, 'to_alipay_dict'):
                params['payment_type'] = self.payment_type.to_alipay_dict()
            else:
                params['payment_type'] = self.payment_type
        if self.pd_code:
            if hasattr(self.pd_code, 'to_alipay_dict'):
                params['pd_code'] = self.pd_code.to_alipay_dict()
            else:
                params['pd_code'] = self.pd_code
        if self.sales_product_code:
            if hasattr(self.sales_product_code, 'to_alipay_dict'):
                params['sales_product_code'] = self.sales_product_code.to_alipay_dict()
            else:
                params['sales_product_code'] = self.sales_product_code
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PayContractDTO()
        if 'account_ext_info' in d:
            o.account_ext_info = d['account_ext_info']
        if 'account_name' in d:
            o.account_name = d['account_name']
        if 'account_no' in d:
            o.account_no = d['account_no']
        if 'account_type' in d:
            o.account_type = d['account_type']
        if 'agreement_no' in d:
            o.agreement_no = d['agreement_no']
        if 'agreement_source' in d:
            o.agreement_source = d['agreement_source']
        if 'biz_pdcode' in d:
            o.biz_pdcode = d['biz_pdcode']
        if 'branch_name' in d:
            o.branch_name = d['branch_name']
        if 'company_code' in d:
            o.company_code = d['company_code']
        if 'currency' in d:
            o.currency = d['currency']
        if 'idempotent_no' in d:
            o.idempotent_no = d['idempotent_no']
        if 'ip_role_id' in d:
            o.ip_role_id = d['ip_role_id']
        if 'ip_role_source' in d:
            o.ip_role_source = d['ip_role_source']
        if 'pay_contract_items' in d:
            o.pay_contract_items = d['pay_contract_items']
        if 'payment_type' in d:
            o.payment_type = d['payment_type']
        if 'pd_code' in d:
            o.pd_code = d['pd_code']
        if 'sales_product_code' in d:
            o.sales_product_code = d['sales_product_code']
        if 'source' in d:
            o.source = d['source']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayTradePaygrowthPayabilityQueryModel(object):

    def __init__(self):
        self._biz_identity = None
        self._real_pay_amount = None
        self._request_from = None
        self._user_id = None

    @property
    def biz_identity(self):
        return self._biz_identity

    @biz_identity.setter
    def biz_identity(self, value):
        self._biz_identity = value
    @property
    def real_pay_amount(self):
        return self._real_pay_amount

    @real_pay_amount.setter
    def real_pay_amount(self, value):
        self._real_pay_amount = value
    @property
    def request_from(self):
        return self._request_from

    @request_from.setter
    def request_from(self, value):
        self._request_from = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_identity:
            if hasattr(self.biz_identity, 'to_alipay_dict'):
                params['biz_identity'] = self.biz_identity.to_alipay_dict()
            else:
                params['biz_identity'] = self.biz_identity
        if self.real_pay_amount:
            if hasattr(self.real_pay_amount, 'to_alipay_dict'):
                params['real_pay_amount'] = self.real_pay_amount.to_alipay_dict()
            else:
                params['real_pay_amount'] = self.real_pay_amount
        if self.request_from:
            if hasattr(self.request_from, 'to_alipay_dict'):
                params['request_from'] = self.request_from.to_alipay_dict()
            else:
                params['request_from'] = self.request_from
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayTradePaygrowthPayabilityQueryModel()
        if 'biz_identity' in d:
            o.biz_identity = d['biz_identity']
        if 'real_pay_amount' in d:
            o.real_pay_amount = d['real_pay_amount']
        if 'request_from' in d:
            o.request_from = d['request_from']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AntfarmProjectTargetInfo import AntfarmProjectTargetInfo


class AntfarmProjectInfo(object):

    def __init__(self):
        self._project_id = None
        self._project_name = None
        self._target_list = None

    @property
    def project_id(self):
        return self._project_id

    @project_id.setter
    def project_id(self, value):
        self._project_id = value
    @property
    def project_name(self):
        return self._project_name

    @project_name.setter
    def project_name(self, value):
        self._project_name = value
    @property
    def target_list(self):
        return self._target_list

    @target_list.setter
    def target_list(self, value):
        if isinstance(value, list):
            self._target_list = list()
            for i in value:
                if isinstance(i, AntfarmProjectTargetInfo):
                    self._target_list.append(i)
                else:
                    self._target_list.append(AntfarmProjectTargetInfo.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.project_id:
            if hasattr(self.project_id, 'to_alipay_dict'):
                params['project_id'] = self.project_id.to_alipay_dict()
            else:
                params['project_id'] = self.project_id
        if self.project_name:
            if hasattr(self.project_name, 'to_alipay_dict'):
                params['project_name'] = self.project_name.to_alipay_dict()
            else:
                params['project_name'] = self.project_name
        if self.target_list:
            if isinstance(self.target_list, list):
                for i in range(0, len(self.target_list)):
                    element = self.target_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.target_list[i] = element.to_alipay_dict()
            if hasattr(self.target_list, 'to_alipay_dict'):
                params['target_list'] = self.target_list.to_alipay_dict()
            else:
                params['target_list'] = self.target_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntfarmProjectInfo()
        if 'project_id' in d:
            o.project_id = d['project_id']
        if 'project_name' in d:
            o.project_name = d['project_name']
        if 'target_list' in d:
            o.target_list = d['target_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class KoubeiMarketingDataIndicatorQueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiMarketingDataIndicatorQueryResponse, self).__init__()
        self._indicator_infos = None
        self._total_size = None

    @property
    def indicator_infos(self):
        return self._indicator_infos

    @indicator_infos.setter
    def indicator_infos(self, value):
        self._indicator_infos = value
    @property
    def total_size(self):
        return self._total_size

    @total_size.setter
    def total_size(self, value):
        self._total_size = value

    def parse_response_content(self, response_content):
        response = super(KoubeiMarketingDataIndicatorQueryResponse, self).parse_response_content(response_content)
        if 'indicator_infos' in response:
            self.indicator_infos = response['indicator_infos']
        if 'total_size' in response:
            self.total_size = response['total_size']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.SubButton import SubButton


class ButtonObject(object):

    def __init__(self):
        self._action_param = None
        self._action_type = None
        self._icon = None
        self._name = None
        self._sub_button = None

    @property
    def action_param(self):
        return self._action_param

    @action_param.setter
    def action_param(self, value):
        self._action_param = value
    @property
    def action_type(self):
        return self._action_type

    @action_type.setter
    def action_type(self, value):
        self._action_type = value
    @property
    def icon(self):
        return self._icon

    @icon.setter
    def icon(self, value):
        self._icon = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def sub_button(self):
        return self._sub_button

    @sub_button.setter
    def sub_button(self, value):
        if isinstance(value, list):
            self._sub_button = list()
            for i in value:
                if isinstance(i, SubButton):
                    self._sub_button.append(i)
                else:
                    self._sub_button.append(SubButton.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.action_param:
            if hasattr(self.action_param, 'to_alipay_dict'):
                params['action_param'] = self.action_param.to_alipay_dict()
            else:
                params['action_param'] = self.action_param
        if self.action_type:
            if hasattr(self.action_type, 'to_alipay_dict'):
                params['action_type'] = self.action_type.to_alipay_dict()
            else:
                params['action_type'] = self.action_type
        if self.icon:
            if hasattr(self.icon, 'to_alipay_dict'):
                params['icon'] = self.icon.to_alipay_dict()
            else:
                params['icon'] = self.icon
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.sub_button:
            if isinstance(self.sub_button, list):
                for i in range(0, len(self.sub_button)):
                    element = self.sub_button[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.sub_button[i] = element.to_alipay_dict()
            if hasattr(self.sub_button, 'to_alipay_dict'):
                params['sub_button'] = self.sub_button.to_alipay_dict()
            else:
                params['sub_button'] = self.sub_button
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ButtonObject()
        if 'action_param' in d:
            o.action_param = d['action_param']
        if 'action_type' in d:
            o.action_type = d['action_type']
        if 'icon' in d:
            o.icon = d['icon']
        if 'name' in d:
            o.name = d['name']
        if 'sub_button' in d:
            o.sub_button = d['sub_button']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayBossBaseProcessTaskTakeModel(object):

    def __init__(self):
        self._memo = None
        self._node = None
        self._operator_id = None
        self._operator_work_no = None
        self._puid = None

    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def node(self):
        return self._node

    @node.setter
    def node(self, value):
        self._node = value
    @property
    def operator_id(self):
        return self._operator_id

    @operator_id.setter
    def operator_id(self, value):
        self._operator_id = value
    @property
    def operator_work_no(self):
        return self._operator_work_no

    @operator_work_no.setter
    def operator_work_no(self, value):
        self._operator_work_no = value
    @property
    def puid(self):
        return self._puid

    @puid.setter
    def puid(self, value):
        self._puid = value


    def to_alipay_dict(self):
        params = dict()
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.node:
            if hasattr(self.node, 'to_alipay_dict'):
                params['node'] = self.node.to_alipay_dict()
            else:
                params['node'] = self.node
        if self.operator_id:
            if hasattr(self.operator_id, 'to_alipay_dict'):
                params['operator_id'] = self.operator_id.to_alipay_dict()
            else:
                params['operator_id'] = self.operator_id
        if self.operator_work_no:
            if hasattr(self.operator_work_no, 'to_alipay_dict'):
                params['operator_work_no'] = self.operator_work_no.to_alipay_dict()
            else:
                params['operator_work_no'] = self.operator_work_no
        if self.puid:
            if hasattr(self.puid, 'to_alipay_dict'):
                params['puid'] = self.puid.to_alipay_dict()
            else:
                params['puid'] = self.puid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossBaseProcessTaskTakeModel()
        if 'memo' in d:
            o.memo = d['memo']
        if 'node' in d:
            o.node = d['node']
        if 'operator_id' in d:
            o.operator_id = d['operator_id']
        if 'operator_work_no' in d:
            o.operator_work_no = d['operator_work_no']
        if 'puid' in d:
            o.puid = d['puid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.PaymentVoucherBelongMerchantInfo import PaymentVoucherBelongMerchantInfo
from alipay.aop.api.domain.VoucherSummary import VoucherSummary
from alipay.aop.api.domain.PaymentVoucherBudgetInfo import PaymentVoucherBudgetInfo
from alipay.aop.api.domain.PaymentVoucherDisplayInfo import PaymentVoucherDisplayInfo
from alipay.aop.api.domain.PaymentVoucherSendRule import PaymentVoucherSendRule
from alipay.aop.api.domain.PaymentVoucherUseRuleDetail import PaymentVoucherUseRuleDetail


class AlipayMarketingActivityVoucherQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingActivityVoucherQueryResponse, self).__init__()
        self._activity_id = None
        self._activity_name = None
        self._activity_status = None
        self._belong_merchant_info = None
        self._publish_end_time = None
        self._publish_start_time = None
        self._summary = None
        self._voucher_budget_info = None
        self._voucher_display_info = None
        self._voucher_send_rule = None
        self._voucher_type = None
        self._voucher_use_rule = None

    @property
    def activity_id(self):
        return self._activity_id

    @activity_id.setter
    def activity_id(self, value):
        self._activity_id = value
    @property
    def activity_name(self):
        return self._activity_name

    @activity_name.setter
    def activity_name(self, value):
        self._activity_name = value
    @property
    def activity_status(self):
        return self._activity_status

    @activity_status.setter
    def activity_status(self, value):
        self._activity_status = value
    @property
    def belong_merchant_info(self):
        return self._belong_merchant_info

    @belong_merchant_info.setter
    def belong_merchant_info(self, value):
        if isinstance(value, PaymentVoucherBelongMerchantInfo):
            self._belong_merchant_info = value
        else:
            self._belong_merchant_info = PaymentVoucherBelongMerchantInfo.from_alipay_dict(value)
    @property
    def publish_end_time(self):
        return self._publish_end_time

    @publish_end_time.setter
    def publish_end_time(self, value):
        self._publish_end_time = value
    @property
    def publish_start_time(self):
        return self._publish_start_time

    @publish_start_time.setter
    def publish_start_time(self, value):
        self._publish_start_time = value
    @property
    def summary(self):
        return self._summary

    @summary.setter
    def summary(self, value):
        if isinstance(value, VoucherSummary):
            self._summary = value
        else:
            self._summary = VoucherSummary.from_alipay_dict(value)
    @property
    def voucher_budget_info(self):
        return self._voucher_budget_info

    @voucher_budget_info.setter
    def voucher_budget_info(self, value):
        if isinstance(value, PaymentVoucherBudgetInfo):
            self._voucher_budget_info = value
        else:
            self._voucher_budget_info = PaymentVoucherBudgetInfo.from_alipay_dict(value)
    @property
    def voucher_display_info(self):
        return self._voucher_display_info

    @voucher_display_info.setter
    def voucher_display_info(self, value):
        if isinstance(value, PaymentVoucherDisplayInfo):
            self._voucher_display_info = value
        else:
            self._voucher_display_info = PaymentVoucherDisplayInfo.from_alipay_dict(value)
    @property
    def voucher_send_rule(self):
        return self._voucher_send_rule

    @voucher_send_rule.setter
    def voucher_send_rule(self, value):
        if isinstance(value, PaymentVoucherSendRule):
            self._voucher_send_rule = value
        else:
            self._voucher_send_rule = PaymentVoucherSendRule.from_alipay_dict(value)
    @property
    def voucher_type(self):
        return self._voucher_type

    @voucher_type.setter
    def voucher_type(self, value):
        self._voucher_type = value
    @property
    def voucher_use_rule(self):
        return self._voucher_use_rule

    @voucher_use_rule.setter
    def voucher_use_rule(self, value):
        if isinstance(value, PaymentVoucherUseRuleDetail):
            self._voucher_use_rule = value
        else:
            self._voucher_use_rule = PaymentVoucherUseRuleDetail.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingActivityVoucherQueryResponse, self).parse_response_content(response_content)
        if 'activity_id' in response:
            self.activity_id = response['activity_id']
        if 'activity_name' in response:
            self.activity_name = response['activity_name']
        if 'activity_status' in response:
            self.activity_status = response['activity_status']
        if 'belong_merchant_info' in response:
            self.belong_merchant_info = response['belong_merchant_info']
        if 'publish_end_time' in response:
            self.publish_end_time = response['publish_end_time']
        if 'publish_start_time' in response:
            self.publish_start_time = response['publish_start_time']
        if 'summary' in response:
            self.summary = response['summary']
        if 'voucher_budget_info' in response:
            self.voucher_budget_info = response['voucher_budget_info']
        if 'voucher_display_info' in response:
            self.voucher_display_info = response['voucher_display_info']
        if 'voucher_send_rule' in response:
            self.voucher_send_rule = response['voucher_send_rule']
        if 'voucher_type' in response:
            self.voucher_type = response['voucher_type']
        if 'voucher_use_rule' in response:
            self.voucher_use_rule = response['voucher_use_rule']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ItemVO import ItemVO


class AlipayOpenMiniItemBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenMiniItemBatchqueryResponse, self).__init__()
        self._result_obj = None

    @property
    def result_obj(self):
        return self._result_obj

    @result_obj.setter
    def result_obj(self, value):
        if isinstance(value, list):
            self._result_obj = list()
            for i in value:
                if isinstance(i, ItemVO):
                    self._result_obj.append(i)
                else:
                    self._result_obj.append(ItemVO.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayOpenMiniItemBatchqueryResponse, self).parse_response_content(response_content)
        if 'result_obj' in response:
            self.result_obj = response['result_obj']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AnttechMorseMarketingSrtaNonanonymousQueryResponse(AlipayResponse):

    def __init__(self):
        super(AnttechMorseMarketingSrtaNonanonymousQueryResponse, self).__init__()
        self._biz_no = None
        self._channel = None
        self._max_amount = None
        self._min_amount = None
        self._need_deduct = None
        self._prize_type = None
        self._threshold = None

    @property
    def biz_no(self):
        return self._biz_no

    @biz_no.setter
    def biz_no(self, value):
        self._biz_no = value
    @property
    def channel(self):
        return self._channel

    @channel.setter
    def channel(self, value):
        self._channel = value
    @property
    def max_amount(self):
        return self._max_amount

    @max_amount.setter
    def max_amount(self, value):
        self._max_amount = value
    @property
    def min_amount(self):
        return self._min_amount

    @min_amount.setter
    def min_amount(self, value):
        self._min_amount = value
    @property
    def need_deduct(self):
        return self._need_deduct

    @need_deduct.setter
    def need_deduct(self, value):
        self._need_deduct = value
    @property
    def prize_type(self):
        return self._prize_type

    @prize_type.setter
    def prize_type(self, value):
        self._prize_type = value
    @property
    def threshold(self):
        return self._threshold

    @threshold.setter
    def threshold(self, value):
        self._threshold = value

    def parse_response_content(self, response_content):
        response = super(AnttechMorseMarketingSrtaNonanonymousQueryResponse, self).parse_response_content(response_content)
        if 'biz_no' in response:
            self.biz_no = response['biz_no']
        if 'channel' in response:
            self.channel = response['channel']
        if 'max_amount' in response:
            self.max_amount = response['max_amount']
        if 'min_amount' in response:
            self.min_amount = response['min_amount']
        if 'need_deduct' in response:
            self.need_deduct = response['need_deduct']
        if 'prize_type' in response:
            self.prize_type = response['prize_type']
        if 'threshold' in response:
            self.threshold = response['threshold']
